@@ -13,7 +13,9 @@ package org.eclipse.cdt.codan.core.cxx.internal.model.cfg;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.HashMap;
+import java.util.LinkedHashMap;
+import java.util.LinkedHashSet;
+import java.util.Map;
 
 import org.eclipse.cdt.codan.core.cxx.Activator;
 import org.eclipse.cdt.codan.core.model.cfg.IBasicBlock;
@@ -27,6 +29,7 @@ import org.eclipse.cdt.codan.core.model.cfg.IPlainNode;
 import org.eclipse.cdt.codan.core.model.cfg.ISingleOutgoing;
 import org.eclipse.cdt.codan.core.model.cfg.IStartNode;
 import org.eclipse.cdt.codan.internal.core.cfg.AbstractBasicBlock;
+import org.eclipse.cdt.codan.internal.core.cfg.ConnectorNode;
 import org.eclipse.cdt.codan.internal.core.cfg.DecisionNode;
 import org.eclipse.cdt.codan.internal.core.cfg.JumpNode;
 import org.eclipse.cdt.core.dom.ast.IASTBreakStatement;
@@ -71,7 +74,7 @@ public class ControlFlowGraphBuilder {
 	CxxNodeFactory factory = new CxxNodeFactory();
 	IConnectorNode outerBreak;
 	IConnectorNode outerContinue;
-	HashMap<String, IBasicBlock> labels = new HashMap<>();
+	Map<String, IBranchNode> labels = new LinkedHashMap<>();
 
 	/**
 	 * Builds the graph.
@@ -80,9 +83,18 @@ public class ControlFlowGraphBuilder {
 		IASTStatement body = def.getBody();
 		start = new CxxStartNode();
 		exits = new ArrayList<>();
-		dead = new ArrayList<>();
+		dead = new LinkedHashSet<>();
 		IBasicBlock last = createSubGraph(start, body);
-		if (!(last instanceof IExitNode) && !deadConnector(last)) {
+		for (IBranchNode label : labels.values()) {
+			IConnectorNode conn = (IConnectorNode) label.getOutgoing();
+			if (conn.getIncomingSize() <= 1 && label.getIncoming() == null)
+				dead.add(label);
+			else {
+				dead.remove(label);
+				dead.remove(conn);
+			}
+		}
+		if (!(last instanceof IExitNode || last instanceof IJumpNode || deadConnector(last))) {
 			returnExit = factory.createExitNode(null);
 			returnExit.setStartNode(start);
 			addOutgoing(last, returnExit);
@@ -177,15 +189,12 @@ public class ControlFlowGraphBuilder {
 		} else if (body instanceof IASTLabelStatement) {
 			IASTLabelStatement ast = (IASTLabelStatement) body;
 			String labelName = ast.getName().toString();
-			IBranchNode labNode = (IBranchNode) labels.get(labelName);
+			IBranchNode labNode = labels.get(labelName);
 			IConnectorNode conn;
 			if (labNode != null) {
 				conn = (IConnectorNode) labNode.getOutgoing();
 				addOutgoing(prev, labNode);
 			} else {
-				// labeled statement contains of connector for jumps, branch for
-				// label
-				// and nested statement
 				conn = createLabelNodes(prev, labelName);
 			}
 			return createSubGraph(conn, ast.getNestedStatement());
@@ -193,14 +202,16 @@ public class ControlFlowGraphBuilder {
 			IASTGotoStatement ast = (IASTGotoStatement) body;
 			String labelName = ast.getName().toString();
 			IConnectorNode conn;
-			IBranchNode labNode = (IBranchNode) labels.get(labelName);
+			IBranchNode labNode = labels.get(labelName);
 			if (labNode != null) {
 				conn = (IConnectorNode) labNode.getOutgoing();
 			} else {
 				conn = createLabelNodes(null, labelName);
 			}
 			IJumpNode gotoNode = factory.createJumpNode();
-			((JumpNode) gotoNode).setJump(conn, labNode != null);
+			boolean backward = labNode != null; // This is not accurate XXX
+			((JumpNode) gotoNode).setJump(conn, backward);
+			((ConnectorNode) conn).addIncoming(gotoNode);
 			addOutgoing(prev, gotoNode);
 			return gotoNode;
 		} else if (body instanceof IASTProblemStatement) {
@@ -271,9 +282,19 @@ public class ControlFlowGraphBuilder {
 		return node;
 	}
 
+	/**
+	 * labeled statement consists of connector for jumps,
+	 * branch for label and statement
+	 * 
+	 * @param prev
+	 * @param labelName
+	 * @return
+	 */
 	protected IConnectorNode createLabelNodes(IBasicBlock prev, String labelName) {
 		IBranchNode branch = factory.createBranchNode(labelName);
-		if (prev != null)
+		if (prev == null || prev instanceof IJumpNode || prev instanceof IExitNode)
+			;// don't do anything, leave dangling branch node
+		else
 			addOutgoing(prev, branch);
 		labels.put(labelName, branch);
 		IConnectorNode conn = factory.createConnectorNode();
@@ -383,8 +404,42 @@ public class ControlFlowGraphBuilder {
 	}
 
 	private IBasicBlock createRangeBasedFor(IBasicBlock prev, ICPPASTRangeBasedForStatement forNode) {
-		// TODO(Alena Laskavaia): Implement proper graph.
-		return createSubGraph(prev, forNode.getBody());
+		// Add initializer
+		IPlainNode init = factory.createPlainNode(forNode.getDeclaration());
+		addOutgoing(prev, init);
+		prev = init;
+		// Add continue connector
+		IConnectorNode beforeCheck = factory.createConnectorNode();
+		addOutgoing(prev, beforeCheck);
+		// Decision node
+		CxxDecisionNode decision = factory.createDecisionNode(forNode.getInitializerClause()); // XXX test expression
+		addOutgoing(beforeCheck, decision);
+		// Add break connector
+		IConnectorNode nBreak = factory.createConnectorNode();
+		decision.setMergeNode(nBreak);
+		// Create body and jump to continue node
+		IBranchNode loopStart = factory.createBranchNode(IBranchNode.THEN);
+		addOutgoing(decision, loopStart);
+		// Set break/continue
+		IConnectorNode nContinue = factory.createConnectorNode();
+		IConnectorNode savedContinue = outerContinue;
+		IConnectorNode savedBreak = outerBreak;
+		outerContinue = nContinue;
+		outerBreak = nBreak;
+		IBasicBlock endBody = createSubGraph(loopStart, forNode.getBody());
+		outerContinue = savedContinue;
+		outerBreak = savedBreak;
+		// inc
+		IPlainNode inc = factory.createPlainNode(); // XXX increment
+		addOutgoing(endBody, nContinue);
+		addOutgoing(nContinue, inc);
+		// Connect with backward link
+		addJump(inc, beforeCheck, true);
+		// Add "else" branch
+		IBranchNode loopEnd = factory.createBranchNode(IBranchNode.ELSE);
+		addOutgoing(decision, loopEnd);
+		addJump(loopEnd, nBreak);
+		return nBreak;
 	}
 
 	protected IBasicBlock createWhile(IBasicBlock prev, IASTWhileStatement body) {
@@ -464,15 +519,15 @@ public class ControlFlowGraphBuilder {
 			return (IJumpNode) prev;
 		if (prev instanceof IExitNode)
 			return null;
-		IJumpNode jump = factory.createJumpNode();
+		JumpNode jump = (JumpNode) factory.createJumpNode();
 		addOutgoing(prev, jump);
-		addOutgoing(jump, conn);
-		((JumpNode) jump).setBackward(backward);
+		jump.setJump(conn, backward);
+		((ConnectorNode) conn).addIncoming(jump);
 		return jump;
 	}
 
 	private void addOutgoing(IBasicBlock prev, IBasicBlock node) {
-		if (prev instanceof IExitNode || prev == null) {
+		if (prev instanceof IExitNode || prev instanceof IJumpNode || prev == null) {
 			dead.add(node);
 			return;
 		}
@@ -500,7 +555,7 @@ public class ControlFlowGraphBuilder {
 		if (node instanceof ICfgData) {
 			IASTNode ast = (IASTNode) ((ICfgData) node).getData();
 			if (ast instanceof IASTExpression) {
-				IValue dvalue = Value.create((IASTExpression) ast, 5);
+				IValue dvalue = Value.create((IASTExpression) ast);
 				Long numericalValue = dvalue.numericalValue();
 				if (numericalValue == null)
 					return false;
