@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008 Institute for Software, HSR Hochschule fuer Technik  
+ * Copyright (c) 2008, 2014 Institute for Software, HSR Hochschule fuer Technik  
  * Rapperswil, University of applied sciences and others
  * All rights reserved. This program and the accompanying materials 
  * are made available under the terms of the Eclipse Public License v1.0 
@@ -20,11 +20,11 @@ import org.eclipse.cdt.core.parser.tests.rewrite.RewriteTester;
  * @author Guido Zgraggen IFS
  */
 public class CommentHandlingTestSuite extends TestSuite {
-	
+
 	public static Test suite() throws Exception {
 		TestSuite suite = new TestSuite(CommentHandlingTestSuite.class.getName());
-		suite.addTest(RewriteTester.suite("CommentTests",
-				"resources/rewrite/CommentHandlingTestSource.rts")); //$NON-NLS-1$ 
+		suite.addTest(RewriteTester.suite("CommentTests", "resources/rewrite/CommentHandlingTestSource.rts")); //$NON-NLS-1$
+		suite.addTest(RewriteTester.suite("CommentMultiFileTests", "resources/rewrite/CommentHandlingWithRewriteTest.rts")); //$NON-NLS-1$  
 		suite.addTestSuite(NodeCommentMapTest.class);
 		return suite;
 	}
