@@ -28,10 +28,12 @@ public class LexerTests extends BaseTestCase {
 	private static final LexerOptions NO_DOLLAR = new LexerOptions();
 	private static final LexerOptions NO_MINMAX = new LexerOptions();
 	private static final LexerOptions SLASH_PERCENT = new LexerOptions();
+	private static final LexerOptions CPP_OPTIONS = new LexerOptions();
 	static {
 		NO_DOLLAR.fSupportDollarInIdentifiers= false;
 		NO_MINMAX.fSupportMinAndMax= false;
 		SLASH_PERCENT.fSupportSlashPercentComments= true;
+		CPP_OPTIONS.fSupportRawStringLiterals= true;
 	}
 	
 	static String TRIGRAPH_REPLACES_CHARS= "#^[]|{}~\\";
@@ -42,7 +44,7 @@ public class LexerTests extends BaseTestCase {
 	}
 
 	private Lexer fLexer;
-	private TestLexerLog fLog= new TestLexerLog();
+	private final TestLexerLog fLog= new TestLexerLog();
 	private int fLastEndOffset;
 
 	public LexerTests() {
@@ -599,51 +601,51 @@ public class LexerTests extends BaseTestCase {
 
 	public void testRawStringLiteral() throws Exception {
 		String lit= "abc0123\\\"'.:; \\\\ \n\"(";
-		init("R\"(" + lit + ")\"");
+		init("R\"(" + lit + ")\"", CPP_OPTIONS);
 		rstr("", lit);
 		eof();
 
-		init("LR\"(" + lit + ")\"");
+		init("LR\"(" + lit + ")\"", CPP_OPTIONS);
 		wrstr("", lit);
 		eof();
 
-		init("u8R\"(" + lit + ")\"");
+		init("u8R\"(" + lit + ")\"", CPP_OPTIONS);
 		utf8rstr("", lit);
 		eof();
 
-		init("uR\"(" + lit + ")\"");
+		init("uR\"(" + lit + ")\"", CPP_OPTIONS);
 		utf16rstr("", lit);
 		eof();
 		
-		init("UR\"(" + lit + ")\"");
+		init("UR\"(" + lit + ")\"", CPP_OPTIONS);
 		utf32rstr("", lit);
 		eof();
 
-		init("R\"ut");
+		init("R\"ut", CPP_OPTIONS);
 		problem(IProblem.SCANNER_UNBOUNDED_STRING, "R\"ut");
 		token(IToken.tSTRING, "R\"ut");
 		eof();
 
-		init("LR\"(ut");
+		init("LR\"(ut", CPP_OPTIONS);
 		problem(IProblem.SCANNER_UNBOUNDED_STRING, "LR\"(ut");
 		token(IToken.tLSTRING, "LR\"(ut");
 		eof();
 		
-		init("uR\"p()");
+		init("uR\"p()", CPP_OPTIONS);
 		problem(IProblem.SCANNER_UNBOUNDED_STRING, "uR\"p()");
 		token(IToken.tUTF16STRING, "uR\"p()");
 		eof();
 		
-		init("UR\"(ut");
+		init("UR\"(ut", CPP_OPTIONS);
 		problem(IProblem.SCANNER_UNBOUNDED_STRING, "UR\"(ut");
 		token(IToken.tUTF32STRING, "UR\"(ut");
 		eof();
 		
-		init("R\"+=(Text)=+\"Text)+=\"");
+		init("R\"+=(Text)=+\"Text)+=\"", CPP_OPTIONS);
 		rstr("+=", "Text)=+\"Text");
 		eof();
 		
-		init("UR uR LR u8R U8R\"\"");
+		init("UR uR LR u8R U8R\"\"", CPP_OPTIONS);
 		id("UR"); ws();
 		id("uR"); ws();
 		id("LR"); ws();
@@ -653,7 +655,7 @@ public class LexerTests extends BaseTestCase {
 	}
 		
 	public void testRawStringLiteralInInactiveCode() throws Exception {
-		init("start\n" + "inactive: Rbla\n" + "#end");
+		init("start\n" + "inactive: Rbla\n" + "#end", CPP_OPTIONS);
 		id("start");
 		nextDirective();
 		token(IToken.tPOUND);
@@ -661,7 +663,7 @@ public class LexerTests extends BaseTestCase {
 		eof();
 
 		// raw string containing a directive
-		init("start\n" + "inactive: uR\"(\n#endif\n)\"\n" + "#end");
+		init("start\n" + "inactive: uR\"(\n#endif\n)\"\n" + "#end", CPP_OPTIONS);
 		id("start");
 		nextDirective();
 		token(IToken.tPOUND);
