@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2010 IBM Corporation and others.
+ * Copyright (c) 2005, 2015 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,12 +10,16 @@
  *     Andrew Ferguson (Symbian)
  *     Markus Schorn (Wind River Systems)
  *     Anton Leherbauer (Wind River Systems)
+ *     Sergey Prigogin (Google)
  *******************************************************************************/
 package org.eclipse.cdt.core.testplugin;
 
 import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
+import java.util.ArrayList;
+import java.util.HashSet;
+import java.util.Set;
 import java.util.zip.ZipFile;
 
 import org.eclipse.cdt.core.CCProjectNature;
@@ -30,6 +34,7 @@ import org.eclipse.cdt.core.model.IBinaryContainer;
 import org.eclipse.cdt.core.model.ICContainer;
 import org.eclipse.cdt.core.model.ICElement;
 import org.eclipse.cdt.core.model.ICProject;
+import org.eclipse.cdt.core.model.IPathEntry;
 import org.eclipse.cdt.core.model.ISourceRoot;
 import org.eclipse.cdt.core.model.ITranslationUnit;
 import org.eclipse.cdt.core.settings.model.ICConfigExtensionReference;
@@ -38,6 +43,7 @@ import org.eclipse.cdt.core.settings.model.ICProjectDescription;
 import org.eclipse.cdt.core.settings.model.ICProjectDescriptionManager;
 import org.eclipse.cdt.core.settings.model.TestCfgDataProvider;
 import org.eclipse.cdt.core.settings.model.util.CDataUtil;
+import org.eclipse.cdt.internal.core.model.InternalCoreModelUtil;
 import org.eclipse.cdt.internal.core.pdom.indexer.IndexerPreferences;
 import org.eclipse.core.resources.IFolder;
 import org.eclipse.core.resources.IProject;
@@ -115,7 +121,7 @@ public class CProjectHelper {
 	}
 
 	/**
-	 * Add the default binary parser if no binary parser configured.
+	 * Adds the default binary parser if no binary parser configured.
 	 * 
 	 * @param project
 	 * @throws CoreException 
@@ -137,28 +143,28 @@ public class CProjectHelper {
 	/**
 	 * Creates a ICProject.
 	 */
-	public static ICProject createNewStileCProject(final String projectName, final String indexerID) throws CoreException {
-		return createNewStileCProject(projectName, indexerID, false);
+	public static ICProject createNewStyleCProject(final String projectName, final String indexerID) throws CoreException {
+		return createNewStyleCProject(projectName, indexerID, false);
 	}
 
 	/**
 	 * Creates a ICProject.
 	 */
-	public static ICProject createNewStileCProject(final String projectName, String providerId, final String indexerID) throws CoreException {
-		return createNewStileCProject(projectName, providerId, indexerID, false);
+	public static ICProject createNewStyleCProject(final String projectName, String providerId, final String indexerID) throws CoreException {
+		return createNewStyleCProject(projectName, providerId, indexerID, false);
 	}
 
 	/**
 	 * Creates a ICProject.
 	 */
-	public static ICProject createNewStileCProject(final String projectName, final String indexerID, boolean markCreating) throws CoreException {
-		return createNewStileCProject(projectName, null, indexerID, markCreating);
+	public static ICProject createNewStyleCProject(final String projectName, final String indexerID, boolean markCreating) throws CoreException {
+		return createNewStyleCProject(projectName, null, indexerID, markCreating);
 	}
 
 	/**
 	 * Creates a ICProject.
 	 */
-	public static ICProject createNewStileCProject(final String projectName, String cfgProviderId, final String indexerID, final boolean markCreating) throws CoreException {
+	public static ICProject createNewStyleCProject(final String projectName, String cfgProviderId, final String indexerID, final boolean markCreating) throws CoreException {
 		final IWorkspace ws = ResourcesPlugin.getWorkspace();
 		final ICProject newProject[] = new ICProject[1];
 		if(cfgProviderId == null)
@@ -260,7 +266,7 @@ public class CProjectHelper {
 	public static ICContainer addCContainer(ICProject cproject, String containerName) throws CoreException {
 		IProject project = cproject.getProject();
 		ICContainer container = null;
-		if (containerName == null || containerName.length() == 0) {
+		if (containerName == null || containerName.isEmpty()) {
 			ICContainer[] conts = cproject.getSourceRoots();
 			if (conts.length > 0) {
 				container = conts[0];
@@ -276,7 +282,7 @@ public class CProjectHelper {
 	}
 
 	/**
-	 * Adds a folder container to a ICProject and imports all files contained in the given Zip file.
+	 * Adds a folder container to a ICProject and imports all files contained in the given zip file.
 	 */
 	public static ICContainer addCContainerWithImport(ICProject cproject, String containerName, ZipFile zipFile)
 			throws InvocationTargetException, CoreException {
@@ -293,24 +299,55 @@ public class CProjectHelper {
 		folder.delete(true, null);
 	}
 
+	/**
+	 * Adds a source root to a C/C++ project.
+	 *
+	 * @param cproject the project to add the source root to
+	 * @param rootName the relative path of the source root
+	 */
+	public static void addSourceRoot(ICProject cproject, String rootName) throws CoreException {
+		IProject project = cproject.getProject();
+		IFolder rootFolder = project.getFolder(rootName);
+		if (!rootFolder.exists()) {
+			rootFolder.create(false, true, null);
+		}
+		IPath rootPath = rootFolder.getFullPath();
+
+		if (!CCorePlugin.getDefault().isNewStyleProject(project)) {
+			InternalCoreModelUtil.addSourceEntry(project, rootFolder, false, null);
+		} else {
+			IPathEntry[] entries = cproject.getRawPathEntries();
+			ArrayList<IPathEntry> newEntries= new ArrayList<>(entries.length + 1);
+			
+			for (IPathEntry entry : entries) {
+				if (entry.getEntryKind() == IPathEntry.CDT_SOURCE && rootPath.equals(entry.getPath())) {
+					return; // The source root exists already.
+				}
+				newEntries.add(entry);
+			}
+			
+			IPathEntry newEntry= CoreModel.newSourceEntry(rootPath);
+			
+			Set<IPathEntry> modified= new HashSet<>();				
+			InternalCoreModelUtil.addExclusionPatterns(newEntry, newEntries, modified);
+			newEntries.add(CoreModel.newSourceEntry(rootPath));
+				
+			cproject.setRawPathEntries(newEntries.toArray(new IPathEntry[newEntries.size()]), null);
+		}
+	}
+
 	/**
 	 * Attempts to find an archive with the given name in the workspace
 	 */
 	public static IArchive findArchive(ICProject testProject, String name) throws CModelException {
-		int x;
-		IArchive[] myArchives;
-		IArchiveContainer archCont;
-		/***************************************************************************************************************************
-		 * Since ArchiveContainer.getArchives does not wait until all the archives in the project have been parsed before returning
-		 * the list, we have to do a sync ArchiveContainer.getChildren first to make sure we find all the archives.
-		 */
-		archCont = testProject.getArchiveContainer();
-		myArchives = archCont.getArchives();
-		if (myArchives.length < 1)
-			return null;
-		for (x = 0; x < myArchives.length; x++) {
-			if (myArchives[x].getElementName().equals(name))
-				return (myArchives[x]);
+		// Since ArchiveContainer.getArchives does not wait until all the archives in the project
+		// have been parsed before returning the list, we have to do a sync
+		// ArchiveContainer.getChildren first to make sure we find all the archives.
+		IArchiveContainer archCont = testProject.getArchiveContainer();
+		IArchive[] myArchives = archCont.getArchives();
+		for (IArchive archive : myArchives) {
+			if (archive.getElementName().equals(name))
+				return archive;
 		}
 		return null;
 	}
@@ -319,16 +356,10 @@ public class CProjectHelper {
 	 * Attempts to find a binary with the given name in the workspace
 	 */
 	public static IBinary findBinary(ICProject testProject, String name) throws CModelException {
-		IBinaryContainer binCont;
-		int x;
-		IBinary[] myBinaries;
-		binCont = testProject.getBinaryContainer();
-		myBinaries = binCont.getBinaries();
-		if (myBinaries.length < 1)
-			return null;
-		for (x = 0; x < myBinaries.length; x++) {
-			if (myBinaries[x].getElementName().equals(name))
-				return (myBinaries[x]);
+		IBinaryContainer binCont = testProject.getBinaryContainer();
+		for (IBinary binary : binCont.getBinaries()) {
+			if (binary.getElementName().equals(name))
+				return binary;
 		}
 		return null;
 	}
@@ -338,14 +369,10 @@ public class CProjectHelper {
 	 */
 	public static IBinary findObject(ICProject testProject, String name) throws CModelException {
 		ICElement[] sourceRoots = testProject.getChildren();
-		for (int i = 0; i < sourceRoots.length; i++) {
-			ISourceRoot root = (ISourceRoot) sourceRoots[i];
-			ICElement[] myElements = root.getChildren();
-			for (int x = 0; x < myElements.length; x++) {
-				if (myElements[x].getElementName().equals(name)) {
-					if (myElements[x] instanceof IBinary) {
-						return ((IBinary) myElements[x]);
-					}
+		for (ICElement root : sourceRoots) {
+			for (ICElement element : ((ISourceRoot) root).getChildren()) {
+				if (element.getElementName().equals(name) && element instanceof IBinary) {
+					return ((IBinary) element);
 				}
 			}
 		}
@@ -353,20 +380,16 @@ public class CProjectHelper {
 	}
 
 	/**
-	 * Attempts to find a TranslationUnit with the given name in the workspace
-	 * @throws InterruptedException 
+	 * Attempts to find a TranslationUnit with the given name in the workspace.
 	 */
-	public static ITranslationUnit findTranslationUnit(ICProject testProject, String name) throws CModelException, InterruptedException {
+	public static ITranslationUnit findTranslationUnit(ICProject testProject, String name)
+			throws CModelException, InterruptedException {
 		for (int j = 0; j < 20; j++) {
 			ICElement[] sourceRoots = testProject.getChildren();
-			for (int i = 0; i < sourceRoots.length; i++) {
-				ISourceRoot root = (ISourceRoot) sourceRoots[i];
-				ICElement[] myElements = root.getChildren();
-				for (int x = 0; x < myElements.length; x++) {
-					if (myElements[x].getElementName().equals(name)) {
-						if (myElements[x] instanceof ITranslationUnit) {
-							return ((ITranslationUnit) myElements[x]);
-						}
+			for (ICElement root : sourceRoots) {
+				for (ICElement element : ((ISourceRoot) root).getChildren()) {
+					if (element.getElementName().equals(name) && element instanceof ITranslationUnit) {
+						return ((ITranslationUnit) element);
 					}
 				}
 			}
@@ -376,16 +399,14 @@ public class CProjectHelper {
 	}
 
 	/**
-	 * Attempts to find an element with the given name in the workspace
+	 * Attempts to find an element with the given name in the workspace.
 	 */
 	public static ICElement findElement(ICProject testProject, String name) throws CModelException {
 		ICElement[] sourceRoots = testProject.getChildren();
-		for (int i = 0; i < sourceRoots.length; i++) {
-			ISourceRoot root = (ISourceRoot) sourceRoots[i];
-			ICElement[] myElements = root.getChildren();
-			for (int x = 0; x < myElements.length; x++) {
-				if (myElements[x].getElementName().equals(name)) {
-					return myElements[x];
+		for (ICElement root : sourceRoots) {
+			for (ICElement element : ((ISourceRoot) root).getChildren()) {
+				if (element.getElementName().equals(name)) {
+					return element;
 				}
 			}
 		}
@@ -410,11 +431,10 @@ public class CProjectHelper {
 					OVERWRITE_QUERY);
 			op.run(monitor);
 		} catch (InterruptedException e) {
-			// should not happen
+			// Should not happen.
 		}
 	}
 
-	
 	public static void importSourcesFromPlugin(ICProject project, Bundle bundle, String sources) throws CoreException {
 		try {
 			String baseDir= FileLocator.toFileURL(FileLocator.find(bundle, new Path(sources), null)).getFile();
@@ -422,21 +442,18 @@ public class CProjectHelper {
 					new File(baseDir), FileSystemStructureProvider.INSTANCE, OVERWRITE_QUERY);
 			importOp.setCreateContainerStructure(false);
 			importOp.run(new NullProgressMonitor());
-		}
-		catch (Exception e) {
+		} catch (Exception e) {
 			throw new CoreException(new Status(IStatus.ERROR, CTestPlugin.PLUGIN_ID, 0, "Import Interrupted", e));
 		}
 	}
 
 	/**
-	 * @return the location of a newly created directory in temporary area.
-	 *    Note that cleanup should be done with {@link ResourceHelper#cleanUp()}.
-	 * @throws IOException
-	 * @throws CoreException 
+	 * Returns the location of a newly created directory in a temporary area.
+	 * Note that cleanup should be done with {@link ResourceHelper#cleanUp()}.
 	 */
 	public static File freshDir() throws IOException, CoreException {
 		IPath folderPath = ResourceHelper.createTemporaryFolder();
-		File folder = new File(folderPath.toOSString());
+		File folder = folderPath.toFile();
 		Assert.assertTrue(folder.exists());
 		Assert.assertTrue(folder.isDirectory());
 		Assert.assertTrue(folder.canWrite());
