@@ -6,18 +6,18 @@
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- *    John Camelon (IBM) - Initial API and implementation
+ *     John Camelon (IBM) - Initial API and implementation
  *******************************************************************************/
 package org.eclipse.cdt.core.dom.ast;
 
 /**
- * This interface represents an object-style macro definition. e.g. #define
- * ONE_TWO_THREE 123
+ * This interface represents an object-style macro definition. e.g.
+ * <pre>
+ * #define ONE_TWO_THREE 123
+ * </pre>
  * 
  * @noextend This interface is not intended to be extended by clients.
  * @noimplement This interface is not intended to be implemented by clients.
  */
-public interface IASTPreprocessorObjectStyleMacroDefinition extends
-		IASTPreprocessorMacroDefinition {
-
+public interface IASTPreprocessorObjectStyleMacroDefinition extends IASTPreprocessorMacroDefinition {
 }
