@@ -6,7 +6,7 @@
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- *    Markus Schorn - initial API and implementation
+ *     Markus Schorn - initial API and implementation
  *******************************************************************************/ 
 package org.eclipse.cdt.core.dom.ast.cpp;
 
@@ -17,7 +17,6 @@ package org.eclipse.cdt.core.dom.ast.cpp;
  * @noextend This interface is not intended to be extended by clients.
  * @noimplement This interface is not intended to be implemented by clients.
  */
-public interface ICPPClassTemplatePartialSpecializationSpecialization extends 
-	ICPPClassTemplatePartialSpecialization, ICPPClassSpecialization {
-
+public interface ICPPClassTemplatePartialSpecializationSpecialization
+		extends	ICPPClassTemplatePartialSpecialization, ICPPClassSpecialization {
 }
