@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2013 IBM Corporation and others.
+ * Copyright (c) 2005, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,6 +12,7 @@
  *     Mike Kucera (IBM) - bug #206952
  *     Sergey Prigogin (Google)
  *     Thomas Corbat (IFS)
+ *     Anders Dahlberg (Ericsson) - bug 84144
  *******************************************************************************/
 package org.eclipse.cdt.internal.core.dom.parser;
 
@@ -23,6 +24,8 @@ import org.eclipse.cdt.core.dom.ast.ASTGenericVisitor;
 import org.eclipse.cdt.core.dom.ast.ASTVisitor;
 import org.eclipse.cdt.core.dom.ast.IASTASMDeclaration;
 import org.eclipse.cdt.core.dom.ast.IASTAttribute;
+import org.eclipse.cdt.core.dom.ast.IASTAttributeOwner;
+import org.eclipse.cdt.core.dom.ast.IASTAttributeSpecifier;
 import org.eclipse.cdt.core.dom.ast.IASTBinaryExpression;
 import org.eclipse.cdt.core.dom.ast.IASTBreakStatement;
 import org.eclipse.cdt.core.dom.ast.IASTCaseStatement;
@@ -49,7 +52,6 @@ import org.eclipse.cdt.core.dom.ast.IASTFileLocation;
 import org.eclipse.cdt.core.dom.ast.IASTFunctionCallExpression;
 import org.eclipse.cdt.core.dom.ast.IASTFunctionDeclarator;
 import org.eclipse.cdt.core.dom.ast.IASTFunctionDefinition;
-import org.eclipse.cdt.core.dom.ast.IASTGotoStatement;
 import org.eclipse.cdt.core.dom.ast.IASTIfStatement;
 import org.eclipse.cdt.core.dom.ast.IASTInitializer;
 import org.eclipse.cdt.core.dom.ast.IASTInitializerClause;
@@ -91,7 +93,6 @@ import org.eclipse.cdt.core.parser.OffsetLimitReachedException;
 import org.eclipse.cdt.core.parser.ParseError;
 import org.eclipse.cdt.core.parser.ParserMode;
 import org.eclipse.cdt.core.parser.util.CharArrayUtils;
-import org.eclipse.cdt.core.parser.util.CollectionUtils;
 import org.eclipse.cdt.internal.core.parser.scanner.ILocationResolver;
 
 /**
@@ -111,7 +112,7 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
 		}
 	}
 
-    protected static class Decl extends Exception {
+    protected static class Decl {
     	public Decl() {
     	}
 
@@ -1846,6 +1847,11 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
      * if both parses succeed then an ambiguity node is returned.
      */
     protected IASTStatement parseDeclarationOrExpressionStatement() throws EndOfFileException, BacktrackException {
+        return parseDeclarationOrExpressionStatement(null);
+    }
+
+    protected IASTStatement parseDeclarationOrExpressionStatement(List<IASTAttributeSpecifier> attributeSpecifiers)
+            throws EndOfFileException, BacktrackException {
         // First attempt to parse an expressionStatement
         // Note: the function style cast ambiguity is handled in expression
         // Since it only happens when we are in a statement
@@ -1856,6 +1862,7 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
         try {
             IASTExpression expression = expression();
             expressionStatement = nodeFactory.newExpressionStatement(expression);
+            addAttributeSpecifiers(attributeSpecifiers, expressionStatement);
             setRange(expressionStatement, expression);
             afterExpression= LA();
 
@@ -1872,6 +1879,9 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
         IASTDeclarationStatement ds = null;
         try {
             IASTDeclaration d = declaration(DeclarationOptions.LOCAL);
+            if (d instanceof IASTAttributeOwner) {
+                addAttributeSpecifiers(attributeSpecifiers, (IASTAttributeOwner) d);
+            }
             ds = nodeFactory.newDeclarationStatement(d);
             setRange(ds, d);
         } catch (BacktrackException b) {
@@ -1980,13 +1990,21 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
     }
 
     protected IASTStatement parseGotoStatement() throws EndOfFileException, BacktrackException {
-        int startOffset = consume().getOffset(); // t_goto
-        IASTName goto_label_name = identifier();
-        int lastOffset = consume(IToken.tSEMI).getEndOffset();
+        int startOffset = consume(IToken.t_goto).getOffset();
+        IASTStatement gotoStatement = null;
 
-        IASTGotoStatement goto_statement = nodeFactory.newGotoStatement(goto_label_name);
-        ((ASTNode) goto_statement).setOffsetAndLength(startOffset, lastOffset - startOffset);
-        return goto_statement;
+        if (LT(1) == IToken.tSTAR)
+        {
+            IASTExpression gotoLabelNameExpression = expression();
+            gotoStatement = nodeFactory.newGotoStatement(gotoLabelNameExpression);
+        } else {
+            IASTName gotoLabelName = identifier();
+            gotoStatement = nodeFactory.newGotoStatement(gotoLabelName);
+        }
+
+        int lastOffset = consume(IToken.tSEMI).getEndOffset();
+        ((ASTNode) gotoStatement).setOffsetAndLength(startOffset, lastOffset - startOffset);
+        return gotoStatement;
     }
 
     protected IASTStatement parseBreakStatement() throws EndOfFileException, BacktrackException {
@@ -2325,13 +2343,16 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
      * @throws BacktrackException
      * @throws EndOfFileException
      */
-    protected List<IASTAttribute> __attribute_decl_seq(boolean allowAttrib, boolean allowDeclspec)
+    protected List<IASTAttributeSpecifier> __attribute_decl_seq(boolean allowAttrib, boolean allowDeclspec)
     		throws BacktrackException, EndOfFileException {
-    	List<IASTAttribute> result = null;
+    	List<IASTAttributeSpecifier> result = null;
         while (true) {
         	final int lt = LTcatchEOF(1);
         	if (allowAttrib && (lt == IGCCToken.t__attribute__)) {
-        		result = CollectionUtils.merge(result, __attribute__());
+        		if (result == null) {
+        			result = new ArrayList<IASTAttributeSpecifier>();
+        		}
+        		result.add(__attribute__());
         	} else if (allowDeclspec && (lt == IGCCToken.t__declspec)) {
         		__declspec();
         	} else {
@@ -2348,11 +2369,11 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
      * @throws BacktrackException
      * @throws EndOfFileException
      */
-    protected List<IASTAttribute> __attribute__() throws BacktrackException, EndOfFileException {
+    protected IASTAttributeSpecifier __attribute__() throws BacktrackException, EndOfFileException {
     	if (LT(1) != IGCCToken.t__attribute__)
     		return null;
 
-    	List<IASTAttribute> result = null;
+    	IASTAttributeSpecifier result = nodeFactory.newGCCAttributeSpecifier();
     	consume();
     	if (LT(1) == IToken.tLPAREN) {
     		consume();
@@ -2365,10 +2386,7 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
 
     			// Allow empty attribute
     			if (lt1 != IToken.tCOMMA) {
-    				IASTAttribute attribute = singleAttribute();
-    				if (result == null)
-    					result = new ArrayList<IASTAttribute>();
-    				result.add(attribute);
+    				result.addAttribute(singleAttribute());
     			}
 
 				// Require comma
@@ -2383,22 +2401,34 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
     	return result;
     }
 
-	private IASTAttribute singleAttribute() throws EndOfFileException, BacktrackException {
+	protected IASTAttribute singleAttribute() throws EndOfFileException, BacktrackException {
 		// Get an identifier including keywords
-		IToken attributeName = identifierOrKeyword();
+		IToken nameToken = identifierOrKeyword();
 		IASTToken argumentClause = null;
+		int endOffset = nameToken.getEndOffset();
+
 		// Check for arguments
 		if (LT(1) == IToken.tLPAREN) {
-			consume();
-			argumentClause = balancedTokenSeq(IToken.tRPAREN);
-			consumeOrEOC(IToken.tRPAREN);
+			int argumentOffset = consume().getEndOffset();
+			argumentClause = balancedTokenSeq(argumentOffset, IToken.tRPAREN);
+			endOffset = consumeOrEOC(IToken.tRPAREN).getEndOffset();
 		}
-		IASTAttribute result = nodeFactory.newAttribute(attributeName.getCharImage(), argumentClause);
-		setRange(result, attributeName.getOffset(), getEndOffset());
+		char[] attributeName = nameToken.getCharImage();
+
+		IASTAttribute result = nodeFactory.newAttribute(attributeName, argumentClause);
+		setRange(result, nameToken.getOffset(), endOffset);
 		return result;
 	}
 
-	private IToken identifierOrKeyword() throws EndOfFileException, BacktrackException {
+	protected void addAttributeSpecifiers(List<IASTAttributeSpecifier> specifiers, IASTAttributeOwner owner) {
+		if (specifiers != null && owner != null) {
+			for (IASTAttributeSpecifier specifier : specifiers) {
+				owner.addAttributeSpecifier(specifier);
+			}
+		}
+	}
+
+	protected IToken identifierOrKeyword() throws EndOfFileException, BacktrackException {
 		IToken t = LA(1);
 		char[] image= t.getCharImage();
 		if (image.length == 0)
@@ -2410,11 +2440,20 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
 		return t;
 	}
 
-	private IASTToken balancedTokenSeq(int endType) throws EndOfFileException, BacktrackException {
-		IASTToken result = null;
+	/**
+	 * Parses sequence of tokens until encountering a token of a given type
+	 * @param offset the offset for the returned token node.
+	 * @param endType the type of the token to stop before
+	 * @return a token sequence, possibly empty but never {@code null}
+	 */
+	protected IASTTokenList balancedTokenSeq(int offset, int endType) 
+			throws EndOfFileException, BacktrackException {
+		IASTTokenList result = nodeFactory.newTokenList();
 		IToken t;
 		while ((t = LA(1)).getType() != endType) {
-			consume();
+			t = consume();
+			result.addToken(createASTToken(t));
+
 			IASTToken token;
 			switch (t.getType()) {
 			case IToken.tLPAREN:
@@ -2430,52 +2469,25 @@ public abstract class AbstractGNUSourceCodeParser implements ISourceCodeParser {
 				break;
 
 			default:
-				token = nodeFactory.newToken(t.getType(), t.getCharImage());
-				setRange(token, t.getOffset(), t.getEndOffset());
-				break;
+				continue;
 			}
-			result = addTokenToSequence(result, token);
+			result.addToken(token);
+			t = consume();
+			token = createASTToken(t);
+			result.addToken(token);
 		}
+
+		setRange(result, offset, t.getEndOffset());
 		return result;
 	}
 
-	/**
-	 * Parses sequence of tokens until encountering a token of a given type
-	 * @param offset the offset for the returned token node.
-	 * @param endType the type of the token to stop before
-	 * @return a token sequence, possibly empty but never {@code null}
-	 */
-	private IASTToken balancedTokenSeq(int offset, int endType) throws EndOfFileException, BacktrackException {
-		IASTToken token = balancedTokenSeq(endType);
-		if (token == null)
-			token = nodeFactory.newTokenList();
-		int endOffset = consumeOrEOC(endType).getEndOffset();
-		setRange(token, offset, endOffset);
+	private IASTToken createASTToken(IToken t) {
+		IASTToken token;
+		token = nodeFactory.newToken(t.getType(), t.getCharImage());
+		setRange(token, t.getOffset(), t.getEndOffset());
 		return token;
 	}
 
-	/**
-	 * Adds a token to a token sequence.
-	 *
-	 * @param sequence the token sequence, may be {@code null}
-	 * @param token the token to add
-	 * @return the modified token sequence that is never {@code null}
-	 */
-	private IASTToken addTokenToSequence(IASTToken sequence, IASTToken token) {
-		if (sequence == null) {
-			sequence = token;
-		} else if (sequence instanceof IASTTokenList) {
-			((IASTTokenList) sequence).addToken(token);
-			adjustLength(sequence, token);
-		} else {
-			IASTTokenList list = nodeFactory.newTokenList();
-			list.addToken(token);
-			setRange(list, token);
-			sequence = list;
-		}
-		return sequence;
-	}
-
 	protected void __declspec() throws BacktrackException, EndOfFileException {
     	IToken token = LA(1);
     	if (token.getType() == IGCCToken.t__declspec) {
