@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2012 Wind River Systems, Inc. and others.
+ * Copyright (c) 2010, 2014 Wind River Systems, Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -56,6 +56,16 @@ public class ProblemFunctionType extends ProblemType implements ICPPFunctionType
 		return false;
 	}
 
+	@Override
+	public boolean hasRefQualifier() {
+		return false;
+	}
+
+	@Override
+	public boolean isRValueReference() {
+		return false;
+	}
+
 	@Override
 	public boolean takesVarArgs() {
 		return false;
