@@ -57,11 +57,7 @@ public class CPPASTCastExpression extends ASTNode implements ICPPASTCastExpressi
 		copy.setTypeId(typeId == null ? null : typeId.copy(style));
 		IASTExpression operand = getOperand();
 		copy.setOperand(operand == null ? null : operand.copy(style));
-		copy.setOffsetAndLength(this);
-		if (style == CopyStyle.withLocations) {
-			copy.setCopyLocation(this);
-		}
-		return copy;
+		return copy(copy, style);
 	}
 
 	@Override
