@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2012 IBM Corporation and others.
+ * Copyright (c) 2004, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -23,28 +23,28 @@ import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTExpression;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTFunctionDeclarator;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTFunctionDefinition;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTParameterDeclaration;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTVirtSpecifier;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTVirtSpecifier.SpecifierKind;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPFunctionScope;
 import org.eclipse.cdt.core.parser.util.ArrayUtil;
 import org.eclipse.cdt.internal.core.dom.parser.ASTQueries;
-import org.eclipse.cdt.internal.core.dom.parser.IASTAmbiguityParent;
 
 /**
  * Represents a function declarator.
  */
-public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPASTFunctionDeclarator,
-		IASTAmbiguityParent {
+public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPASTFunctionDeclarator {
     private ICPPASTParameterDeclaration[] parameters;
     private IASTTypeId[] typeIds = NO_EXCEPTION_SPECIFICATION;
     private ICPPASTExpression noexceptExpression;
     private IASTTypeId trailingReturnType;
+    private ICPPASTVirtSpecifier[] virtSpecifiers = NO_VIRT_SPECIFIERS;
     
     private boolean varArgs;
     private boolean pureVirtual;
     private boolean isVolatile;
     private boolean isConst;
     private boolean isMutable;
-    private boolean isOverride;
-    private boolean isFinal;
+    private RefQualifier refQualifier;
     
     private ICPPFunctionScope scope;
     
@@ -68,8 +68,7 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
 		copy.isVolatile = isVolatile;
 		copy.isConst = isConst;
 		copy.isMutable = isMutable;
-		copy.isOverride = isOverride;
-		copy.isFinal = isFinal;
+		copy.refQualifier = refQualifier;
 
 		for (IASTParameterDeclaration param : getParameters()) {
 			copy.addParameterDeclaration(param == null ? null : param.copy(style));
@@ -84,6 +83,9 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
 		if (trailingReturnType != null) {
 			copy.setTrailingReturnType(trailingReturnType.copy(style));
 		}
+		for (ICPPASTVirtSpecifier virtSpecifier : getVirtSpecifiers()) {
+			copy.addVirtSpecifier(virtSpecifier.copy(style));
+		}
 		return copy(copy, style);
 	}
 
@@ -213,6 +215,17 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
     }
 
     @Override
+	public RefQualifier getRefQualifier() {
+		return refQualifier;
+	}
+
+    @Override
+	public void setRefQualifier(RefQualifier value) {
+        assertNotFrozen();
+		refQualifier = value;
+	}
+
+	@Override
 	@Deprecated
     public org.eclipse.cdt.core.dom.ast.cpp.ICPPASTConstructorChainInitializer[] getConstructorChain() {
     	if (ASTQueries.findTypeRelevantDeclarator(this) == this) {
@@ -265,9 +278,10 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
 		}
 
 		IASTTypeId[] ids = getExceptionSpecification();
-		for (int i = 0; i < ids.length; i++) {
-			if (!ids[i].accept(action))
+		for (IASTTypeId id : ids) {
+			if (!id.accept(action)) {
 				return false;
+			}
 		}
 
 		if (noexceptExpression != null && noexceptExpression != NOEXCEPT_DEFAULT) {
@@ -277,6 +291,13 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
 		
 		if (trailingReturnType != null && !trailingReturnType.accept(action)) 
 			return false;
+		
+		ICPPASTVirtSpecifier[] virtSpecifiers = getVirtSpecifiers();
+		for (ICPPASTVirtSpecifier virtSpecifier : virtSpecifiers) {
+			if (!virtSpecifier.accept(action)) {
+				return false;
+			}
+		}
 
 		return super.postAccept(action);
 	}
@@ -298,23 +319,49 @@ public class CPPASTFunctionDeclarator extends CPPASTDeclarator implements ICPPAS
 
 	@Override
 	public boolean isOverride() {
-		return isOverride;
+		for (ICPPASTVirtSpecifier virtSpecifier : getVirtSpecifiers()) {
+			if (virtSpecifier.getKind() == SpecifierKind.Override) {
+				return true;
+			}
+		}
+		return false;
 	}
 
 	@Override
 	public void setOverride(boolean value) {
 		assertNotFrozen();
-		this.isOverride = value;
+		// Do nothing here. Use addVirtSpecifier() instead.
 	}
 
 	@Override
 	public boolean isFinal() {
-		return isFinal;
+		for (ICPPASTVirtSpecifier virtSpecifier : getVirtSpecifiers()) {
+			if (virtSpecifier.getKind() == SpecifierKind.Final) {
+				return true;
+			}
+		}
+		return false;
 	}
 
 	@Override
 	public void setFinal(boolean value) {
 		assertNotFrozen();
-		this.isFinal = value;
+		// Do nothing here. Use addVirtSpecifier() instead.
+	}
+
+	@Override
+	public ICPPASTVirtSpecifier[] getVirtSpecifiers() {
+        return virtSpecifiers = ArrayUtil.trim(virtSpecifiers);
+	}
+
+	@Override
+	public void addVirtSpecifier(ICPPASTVirtSpecifier virtSpecifier) {
+        assertNotFrozen();
+    	if (virtSpecifier != null) {
+    		assert virtSpecifiers != null;
+    		virtSpecifiers = ArrayUtil.append(virtSpecifiers, virtSpecifier);
+    		virtSpecifier.setParent(this);
+			virtSpecifier.setPropertyInParent(EXCEPTION_TYPEID);
+    	}
 	}
 }
