@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013 Nathan Ridge.
+ * Copyright (c) 2013, 2014 Nathan Ridge.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     Nathan Ridge - Initial API and implementation
+ *     Sergey Prigogin (Google)
  *******************************************************************************/
 package org.eclipse.cdt.internal.core.dom.parser.cpp;
 
@@ -19,13 +20,15 @@ import org.eclipse.cdt.core.dom.ast.cpp.ICPPTemplateParameterMap;
 /**
  * Binding for a specialization of an enumerator.
  */
-public class CPPEnumeratorSpecialization extends CPPSpecialization implements IEnumerator {
+public class CPPEnumeratorSpecialization extends CPPSpecialization implements ICPPInternalEnumerator {
 	private final IValue fValue;
+	private final IType fInternalType;
 
 	public CPPEnumeratorSpecialization(IEnumerator specialized, ICPPEnumerationSpecialization owner,
-			ICPPTemplateParameterMap argumentMap, IValue value) {
+			ICPPTemplateParameterMap argumentMap, IValue value, IType internalType) {
 		super(specialized, owner, argumentMap);
 		fValue = value;
+		fInternalType = internalType;
 	}
 
 	@Override
@@ -35,11 +38,23 @@ public class CPPEnumeratorSpecialization extends CPPSpecialization implements IE
 
 	@Override
 	public IType getType() {
-		return getOwner();
+		ICPPEnumerationSpecialization owner = getOwner();
+		if (((CPPEnumerationSpecialization) owner).isInitializing()) {
+		    // During enumeration instantiation enumerators can be referenced only by initializer
+			// expressions of other enumerators of the same enumeration. Return the internal type
+			// of the enumerator ([dcl.enum] 7.2-5).
+			return fInternalType;
+		}
+		return owner;
 	}
 
 	@Override
 	public IValue getValue() {
 		return fValue;
 	}
+
+	@Override
+	public IType getInternalType() {
+		return fInternalType;
+	}
 }
