@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2013 IBM Corporation and others.
+ * Copyright (c) 2004, 2015 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -28,6 +28,10 @@ import java.util.HashSet;
 import java.util.Set;
 
 import org.eclipse.cdt.core.dom.ast.DOMException;
+import org.eclipse.cdt.core.dom.ast.IASTEqualsInitializer;
+import org.eclipse.cdt.core.dom.ast.IASTExpression;
+import org.eclipse.cdt.core.dom.ast.IASTInitializer;
+import org.eclipse.cdt.core.dom.ast.IASTInitializerClause;
 import org.eclipse.cdt.core.dom.ast.IASTNode;
 import org.eclipse.cdt.core.dom.ast.IASTTranslationUnit;
 import org.eclipse.cdt.core.dom.ast.IArrayType;
@@ -40,15 +44,20 @@ import org.eclipse.cdt.core.dom.ast.IFunctionType;
 import org.eclipse.cdt.core.dom.ast.IPointerType;
 import org.eclipse.cdt.core.dom.ast.IProblemBinding;
 import org.eclipse.cdt.core.dom.ast.IQualifierType;
+import org.eclipse.cdt.core.dom.ast.IScope;
+import org.eclipse.cdt.core.dom.ast.ISemanticProblem;
 import org.eclipse.cdt.core.dom.ast.IType;
 import org.eclipse.cdt.core.dom.ast.ITypedef;
 import org.eclipse.cdt.core.dom.ast.IValue;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTConstructorInitializer;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTInitializerList;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPBase;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPClassType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPFunction;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPFunctionType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPMethod;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPNamespace;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPNamespaceAlias;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPPointerToMemberType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPReferenceType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPSpecialization;
@@ -59,7 +68,9 @@ import org.eclipse.cdt.core.parser.util.ArrayUtil;
 import org.eclipse.cdt.core.parser.util.CharArraySet;
 import org.eclipse.cdt.core.parser.util.CharArrayUtils;
 import org.eclipse.cdt.core.parser.util.ObjectSet;
+import org.eclipse.cdt.internal.core.dom.parser.ASTTranslationUnit;
 import org.eclipse.cdt.internal.core.dom.parser.ITypeContainer;
+import org.eclipse.cdt.internal.core.dom.parser.Value;
 import org.eclipse.cdt.internal.core.dom.parser.cpp.CPPASTTranslationUnit;
 import org.eclipse.cdt.internal.core.dom.parser.cpp.CPPClosureType;
 import org.eclipse.cdt.internal.core.dom.parser.cpp.CPPFunctionType;
@@ -102,6 +113,7 @@ public class SemanticUtil {
 	 * Returns an array of ICPPMethod objects representing all conversion operators
 	 * declared by the specified class, and the implicitly generated conversion
 	 * operator for a closure type. This does not include inherited methods.
+	 *
 	 * @param clazz
 	 * @return an array of conversion operators.
 	 */
@@ -134,7 +146,8 @@ public class SemanticUtil {
 	/**
 	 * Returns an array of ICPPMethod objects representing all conversion operators
 	 * declared by the specified class and its ancestors. This includes inherited
-	 * methods, and the implicitly generated conversion operator for a closure type. 
+	 * methods, and the implicitly generated conversion operator for a closure type.
+	 *
 	 * @param clazz
 	 * @return an array of conversion operators.
 	 */
@@ -153,12 +166,12 @@ public class SemanticUtil {
 	 * @throws DOMException
 	 */
 	public static ObjectSet<ICPPClassType> inheritanceClosure(ICPPClassType root, IASTNode point) throws DOMException {
-		ObjectSet<ICPPClassType> done= new ObjectSet<ICPPClassType>(2);
-		ObjectSet<ICPPClassType> current= new ObjectSet<ICPPClassType>(2);
+		ObjectSet<ICPPClassType> done= new ObjectSet<>(2);
+		ObjectSet<ICPPClassType> current= new ObjectSet<>(2);
 		current.put(root);
 
 		for (int count = 0; count < CPPSemantics.MAX_INHERITANCE_DEPTH && !current.isEmpty(); count++) {
-			ObjectSet<ICPPClassType> next= new ObjectSet<ICPPClassType>(2);
+			ObjectSet<ICPPClassType> next= new ObjectSet<>(2);
 
 			for (int i = 0; i < current.size(); i++) {
 				ICPPClassType clazz= current.keyAt(i);
@@ -344,7 +357,8 @@ public class SemanticUtil {
 			if (ret == r && params == ps) {
 				return type;
 			}
-			return new CPPFunctionType(ret, params, ft.isConst(), ft.isVolatile(), ft.takesVarArgs());
+			return new CPPFunctionType(ret, params, ft.isConst(), ft.isVolatile(),
+					ft.hasRefQualifier(), ft.isRValueReference(), ft.takesVarArgs());
 		}
 
 		if (type instanceof ITypedef) {
@@ -394,7 +408,7 @@ public class SemanticUtil {
 		if (newNestedType == null)
 			return type;
 
-		// Bug 249085 make sure not to add unnecessary qualifications
+		// Do not to add unnecessary qualifications (bug 24908). 
 		if (type instanceof IQualifierType) {
 			IQualifierType qt= (IQualifierType) type;
 			return addQualifiers(newNestedType, qt.isConst(), qt.isVolatile(), false);
@@ -450,39 +464,91 @@ public class SemanticUtil {
 		}
 	}
 
-	public static IType mapToAST(IType type, IASTNode node) {
-		if (node == null)
-			return type;
-
-		if (type instanceof IFunctionType) {
-			final ICPPFunctionType ft = (ICPPFunctionType) type;
-			final IType r = ft.getReturnType();
-			final IType ret = mapToAST(r, node);
-			if (ret == r) {
-				return type;
+	/**
+	 * Checks if the given type is problem-free.
+	 */
+	public static boolean isValidType(IType t) {
+		while (true) {
+			if (t instanceof ISemanticProblem) {
+				return false;
+			} else if (t instanceof IFunctionType) {
+				IFunctionType ft= (IFunctionType) t;
+				for (IType parameterType : ft.getParameterTypes()) {
+					if (!isValidType(parameterType))
+						return false;
+				}
+				t= ft.getReturnType();
+			} else if (t instanceof ICPPPointerToMemberType) {
+				ICPPPointerToMemberType mptr= (ICPPPointerToMemberType) t;
+				if (!isValidType(mptr.getMemberOfClass()))
+					return false;
+				t= mptr.getType();
+			} else if (t instanceof ITypeContainer) {
+				t= ((ITypeContainer) t).getType();
+			} else {
+				return true;
 			}
-			return new CPPFunctionType(ret, ft.getParameterTypes(), ft.isConst(), ft.isVolatile(), ft.takesVarArgs());
 		}
-		if (type instanceof ITypeContainer) {
-			final ITypeContainer tc = (ITypeContainer) type;
-			final IType nestedType= tc.getType();
-			if (nestedType == null)
-				return type;
+	}
 
-			IType newType= mapToAST(nestedType, node);
-			if (newType != nestedType) {
-				return replaceNestedType(tc, newType);
-			}
-			return type;
-		} else if (type instanceof ICPPClassType && type instanceof IIndexBinding) {
-			IASTTranslationUnit tu = node.getTranslationUnit();
-			if (tu instanceof CPPASTTranslationUnit) {
-				return ((CPPASTTranslationUnit) tu).mapToAST((ICPPClassType) type, node);
+	public static IType mapToAST(IType type, IASTNode point) {
+		if (point != null && type instanceof IIndexBinding && type instanceof ICPPClassType) {
+			IASTTranslationUnit ast = point.getTranslationUnit();
+			if (ast instanceof CPPASTTranslationUnit) {
+				return ((CPPASTTranslationUnit) ast).mapToAST((ICPPClassType) type, point);
 			}
 		}
 		return type;
 	}
 
+	public static ICPPTemplateArgument[] mapToAST(ICPPTemplateArgument[] args, IASTNode point) {
+		if (point == null)
+			return args;
+
+		// Don't create a new array until it's really needed.
+		ICPPTemplateArgument[] result = args;
+		for (int i = 0; i < args.length; i++) {
+			final ICPPTemplateArgument arg = args[i];
+			ICPPTemplateArgument newArg = arg;
+			if (arg != null) {
+				newArg = mapToAST(arg, point);
+				if (result != args) {
+					result[i] = newArg;
+				} else if (arg != newArg) {
+					result = new ICPPTemplateArgument[args.length];
+					if (i > 0) {
+						System.arraycopy(args, 0, result, 0, i);
+					}
+					result[i] = newArg;
+				}
+			}
+		}
+		return result;
+	}
+
+	public static ICPPTemplateArgument mapToAST(ICPPTemplateArgument arg, IASTNode point) {
+		IType type = arg.getTypeValue();
+		if (type != null) {
+			IType mappedType = mapToAST(type, point);
+			IType originalType = arg.getOriginalTypeValue();
+			IType mappedOriginalType = originalType == type ? mappedType : mapToAST(originalType, point);
+			if (mappedType != type || mappedOriginalType != originalType) {
+				return new CPPTemplateTypeArgument(mappedType, mappedOriginalType);
+			}
+		}
+		return arg;
+	}
+
+	public static IScope mapToAST(IScope scope, IASTNode point) {
+		if (point != null) {
+			IASTTranslationUnit ast = point.getTranslationUnit();
+			if (ast instanceof ASTTranslationUnit) {
+				return ((ASTTranslationUnit) ast).mapToASTScope(scope);
+			}
+		}
+		return scope;
+	}
+
 	public static IType[] getSimplifiedTypes(IType[] types) {
 		// Don't create a new array until it's really needed.
 		IType[] result = types;
@@ -583,35 +649,52 @@ public class SemanticUtil {
 	}
 
 	/**
-	 * Returns <code>true</code> if two bindings have the same owner.
+	 * Returns {@code true} if two bindings have the same owner.
 	 */
-	public static boolean isSameOwner(IBinding owner1, IBinding owner2) {
-		// Ignore anonymous namespaces
-		while (owner1 instanceof ICPPNamespace && owner1.getNameCharArray().length == 0)
-			owner1= owner1.getOwner();
-		// Ignore anonymous namespaces
-		while (owner2 instanceof ICPPNamespace && owner2.getNameCharArray().length == 0)
-			owner2= owner2.getOwner();
-
-		if (owner1 == null)
-			return owner2 == null;
-		if (owner2 == null)
+	public static boolean haveSameOwner(IBinding b1, IBinding b2) {
+		if (b1 == b2)
+			return true;
+		b1 = b1.getOwner();
+		b2 = b2.getOwner();
+		if (b1 == b2)
+			return true;
+		if (b1 instanceof IType) {
+			if (b2 instanceof IType)
+				return ((IType) b1).isSameType((IType) b2);
 			return false;
-
-		if (owner1 instanceof IType) {
-			if (owner2 instanceof IType) {
-				return ((IType) owner1).isSameType((IType) owner2);
-			}
-		} else if (owner1 instanceof ICPPNamespace) {
-			if (owner2 instanceof ICPPNamespace) {
-				if (!CharArrayUtils.equals(owner1.getNameCharArray(), owner2.getNameCharArray()))
-					return false;
-				return isSameOwner(owner1.getOwner(), owner2.getOwner());
-			}
 		}
+		if (b1 instanceof ICPPNamespace && b2 instanceof ICPPNamespace)
+			return isSameNamespace((ICPPNamespace) b1, (ICPPNamespace) b2);
 		return false;
 	}
 
+	/**
+	 * Returns {@code true} if the two given bindings represent the same type or namespace.
+	 */
+	public static boolean isSameNamespace(ICPPNamespace ns1, ICPPNamespace ns2) {
+		IBinding b1 = ns1;
+		IBinding b2 = ns2;
+
+		while (true) {
+			for (int i = 0; b1 instanceof ICPPNamespaceAlias && i < 20; i++)
+				b1= ((ICPPNamespaceAlias) b1).getBinding();
+			for (int i = 0; b2 instanceof ICPPNamespaceAlias && i < 20; i++)
+				b2= ((ICPPNamespaceAlias) b2).getBinding();
+	
+			if (b1 == null)
+				return b2 == null;
+			if (b2 == null)
+				return false;
+	
+			if (!(b1 instanceof ICPPNamespace) || !(b2 instanceof ICPPNamespace))
+				return false;
+			if (!CharArrayUtils.equals(b1.getNameCharArray(), b2.getNameCharArray()))
+				return false;
+			b1 = b1.getOwner();
+			b2 = b2.getOwner();
+		}
+	}
+
 	public static boolean isVoidType(IType ptype) {
 		while (ptype instanceof ITypedef) {
 			ptype= ((ITypedef) ptype).getType();
@@ -633,15 +716,16 @@ public class SemanticUtil {
 	}
 
 	/**
-	 * Calculates the number of edges in the inheritance path of <code>type</code> to
-	 * <code>ancestorToFind</code>, returning -1 if no inheritance relationship is found.
+	 * Calculates the number of edges in the inheritance path of {@code type} to
+	 * {@code ancestorToFind}, returning -1 if no inheritance relationship is found.
+	 *
 	 * @param type the class to search upwards from
 	 * @param baseClass the class to find in the inheritance graph
 	 * @return the number of edges in the inheritance graph, or -1 if the specified classes have
-	 * no inheritance relation
+	 * 	   no inheritance relation
 	 */
 	public static final int calculateInheritanceDepth(IType type, IType baseClass, IASTNode point) {
-		return calculateInheritanceDepth(CPPSemantics.MAX_INHERITANCE_DEPTH, new HashSet<Object>(), type, baseClass, point);
+		return calculateInheritanceDepth(CPPSemantics.MAX_INHERITANCE_DEPTH, new HashSet<>(), type, baseClass, point);
 	}
 
 	private static final int calculateInheritanceDepth(int maxdepth, Set<Object> hashSet, IType type, IType baseClass, IASTNode point) {
@@ -655,13 +739,16 @@ public class SemanticUtil {
 				clazz= (ICPPClassType) ((ICPPDeferredClassInstance) clazz).getSpecializedBinding();
 			}
 
+			// The base classes may have changed since the definition of clazz was indexed.
+			clazz = (ICPPClassType) mapToAST(clazz, point);
+
 			for (ICPPBase cppBase : ClassTypeHelper.getBases(clazz, point)) {
 				IBinding base= cppBase.getBaseClass();
 				if (base instanceof IType && hashSet.add(base)) {
 					IType tbase= (IType) base;
 					if (tbase.isSameType(baseClass) ||
-							(baseClass instanceof ICPPSpecialization &&  // allow some flexibility with templates
-							((IType)((ICPPSpecialization) baseClass).getSpecializedBinding()).isSameType(tbase))) {
+							(baseClass instanceof ICPPSpecialization && // Allow some flexibility with templates.  
+							((IType) ((ICPPSpecialization) baseClass).getSpecializedBinding()).isSameType(tbase))) {
 						return 1;
 					}
 
@@ -719,4 +806,45 @@ public class SemanticUtil {
 		}
 		return minValue;
 	}
+
+	public static int findSameType(IType type, IType[] types) {
+		for (int i = 0; i < types.length; i++) {
+			if (type.isSameType(types[i]))
+				return i;
+		}
+		return -1;
+	}
+	
+	/**
+	 * Returns the value of the initializer of a variable.
+	 *
+	 * @param init the initializer's AST node
+	 * @param type the type of the variable
+	 */
+	public static IValue getValueOfInitializer(IASTInitializer init, IType type) {
+		IASTInitializerClause clause= null;
+		if (init instanceof IASTEqualsInitializer) {
+			clause= ((IASTEqualsInitializer) init).getInitializerClause();
+		} else if (init instanceof ICPPASTConstructorInitializer) {
+			IASTInitializerClause[] args= ((ICPPASTConstructorInitializer) init).getArguments();
+			if (args.length == 1 && args[0] instanceof IASTExpression) {
+				IType typeUpToPointers= SemanticUtil.getUltimateTypeUptoPointers(type);
+				if (typeUpToPointers instanceof IPointerType || typeUpToPointers instanceof IBasicType) {
+					clause= args[0];
+				}
+			}
+		} else if (init instanceof ICPPASTInitializerList) {
+			ICPPASTInitializerList list= (ICPPASTInitializerList) init;
+			switch (list.getSize()) {
+			case 0:
+				return Value.create(0);
+			case 1:
+				clause= list.getClauses()[0];
+			}
+		}
+		if (clause instanceof IASTExpression) {
+			return Value.create((IASTExpression) clause);
+		}
+		return Value.UNKNOWN;
+	}
 }
