@@ -13,14 +13,12 @@ package org.eclipse.cdt.internal.core.index.provider;
 import org.eclipse.osgi.util.NLS;
 
 public class Messages extends NLS {
-	private static final String BUNDLE_NAME = "org.eclipse.cdt.internal.core.index.provider.messages"; //$NON-NLS-1$
-
 	public static String IndexProviderManager_InvalidIndexProvider;
 	public static String IndexProviderManager_NoCompatibleFragmentsAvailable;
 
 	static {
-		// Initialize resource bundle
-		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
+		// Initialize resource bundle.
+		NLS.initializeMessages(Messages.class.getName(), Messages.class);
 	}
 
 	private Messages() {
