@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013 Google, Inc and others.
+ * Copyright (c) 2013, 2014 Google, Inc and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,11 +10,11 @@
  *******************************************************************************/
 package org.eclipse.cdt.internal.core.pdom.dom.cpp;
 
-import org.eclipse.cdt.core.dom.ast.IEnumerator;
+import org.eclipse.cdt.internal.core.dom.parser.cpp.ICPPInternalEnumerator;
 import org.eclipse.cdt.internal.core.pdom.dom.IPDOMBinding;
 
 /**
  * Interface for a c++ enumerator stored in the index.
  */
-public interface IPDOMCPPEnumerator extends IEnumerator, IPDOMBinding {
+public interface IPDOMCPPEnumerator extends ICPPInternalEnumerator, IPDOMBinding {
 }
