@@ -13,11 +13,9 @@ package org.eclipse.cdt.internal.core.envvar;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
-public class Messages {
-	private static final String BUNDLE_NAME = "org.eclipse.cdt.internal.core.envvar.messages"; //$NON-NLS-1$
-
-	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
-			.getBundle(BUNDLE_NAME);
+class Messages {
+	private static final ResourceBundle RESOURCE_BUNDLE =
+			ResourceBundle.getBundle(Messages.class.getName());
 
 	private Messages() {
 	}
