@@ -6,32 +6,22 @@
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * Bala Torati (Symbian) - Initial API and implementation
+ *     Bala Torati (Symbian) - Initial API and implementation
  *******************************************************************************/
 package org.eclipse.cdt.core.templateengine;
 
-import java.util.MissingResourceException;
-import java.util.ResourceBundle;
-
+/**
+ * @noreference This class is not intended to be referenced by clients.
+ * @deprecated Provide your own messages.
+ */
+@Deprecated
 public class TemplateEngineMessages {
-	private static final String BUNDLE_NAME = "org.eclipse.cdt.core.templateengine.messages"; //$NON-NLS-1$
-
-	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
-			.getBundle(BUNDLE_NAME);
-
-	/**
-	 * @since 5.6
-	 */
-	public static String ProcessRunner_missingArg;
-
 	private TemplateEngineMessages() {
 	}
 
+	public static String ProcessRunner_missingArg;
+
 	public static String getString(String key) {
-		try {
-			return RESOURCE_BUNDLE.getString(key);
-		} catch (MissingResourceException e) {
-			return '!' + key + '!';
-		}
+		throw new UnsupportedOperationException();
 	}
 }
