@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Google, Inc and others.
+ * Copyright (c) 2009, 2014 Google, Inc and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -157,6 +157,11 @@ public class AddIncludeTest extends BaseTestCase {
 		select("XXX");
 		assertAddIncludeResult();
 	}
+
+	public void testInsertionPoint_435340() throws Exception {
+		select("A435340");
+		assertAddIncludeResult();
+	}
 	
 	public void testTemplate_306670() throws Exception {
 		select("func306670");
