@@ -6,7 +6,7 @@
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * Norbert Ploett (Seimens) - Initial Contribution
+ *     Norbert Ploett (Seimens) - Initial Contribution
  *******************************************************************************/
 package org.eclipse.cdt.ui.tests.text.contentassist;
 
@@ -17,14 +17,11 @@ import org.eclipse.cdt.ui.text.contentassist.IProposalFilter;
  * Dummy filter implementation for testing purposes
  */
 public class TestProposalFilter implements IProposalFilter {
-
 	/**
 	 * This dummy filter method will return the original proposals unmodified.
 	 */
 	@Override
-	public ICCompletionProposal[] filterProposals(
-			ICCompletionProposal[] proposals) {
+	public ICCompletionProposal[] filterProposals(ICCompletionProposal[] proposals) {
 		return proposals ;
 	}
-
 }
