@@ -37,7 +37,6 @@ public class IncludeCreationContext extends InclusionContext {
 	private final Set<IPath> fHeadersToInclude;
 	private final Set<IPath> fHeadersAlreadyIncluded;
 	private final Set<IPath> fHeadersIncludedPreviously;
-	private String fSourceContents;
 
 	public IncludeCreationContext(ITranslationUnit tu, IIndex index) {
 		super(tu);
@@ -47,13 +46,6 @@ public class IncludeCreationContext extends InclusionContext {
 		fHeadersIncludedPreviously = new HashSet<>();
 	}
 
-	public String getSourceContents() {
-		if (fSourceContents == null) {
-			fSourceContents = new String(getTranslationUnit().getContents());
-		}
-		return fSourceContents;
-	}
-
 	public final IIndex getIndex() {
 		return fIndex;
 	}
