@@ -59,8 +59,10 @@ import org.eclipse.cdt.core.dom.ast.IParameter;
 import org.eclipse.cdt.core.dom.ast.IProblemBinding;
 import org.eclipse.cdt.core.dom.ast.IType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTTemplateDeclaration;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTTemplateId;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTTranslationUnit;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTUsingDeclaration;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPAliasTemplateInstance;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPFunction;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPMethod;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPSpecialization;
@@ -175,6 +177,8 @@ class OpenDeclarationsJob extends Job implements ASTRunnable {
 			if (parent instanceof IASTPreprocessorIncludeStatement) {
 				openInclude(((IASTPreprocessorIncludeStatement) parent));
 				return Status.OK_STATUS;
+			} else if (parent instanceof ICPPASTTemplateId) {
+				sourceName = (IASTName) parent;
 			}
 			NameKind kind = getNameKind(sourceName);
 			IBinding b = sourceName.resolveBinding();
@@ -254,6 +258,9 @@ class OpenDeclarationsJob extends Job implements ASTRunnable {
 	}
 
 	private IName[] findDeclNames(IASTTranslationUnit ast, NameKind kind, IBinding binding) throws CoreException {
+		if (binding instanceof ICPPAliasTemplateInstance) {
+			binding = ((ICPPAliasTemplateInstance) binding).getTemplateDefinition();
+		}
 		IName[] declNames = findNames(fIndex, ast, kind, binding);
 		// Bug 207320, handle template instances.
 		while (declNames.length == 0 && binding instanceof ICPPSpecialization) {
@@ -795,4 +802,4 @@ class OpenDeclarationsJob extends Job implements ASTRunnable {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
