@@ -79,6 +79,7 @@ public final class CIndenter {
 		final int prefContinuationIndent;
 		final boolean prefHasTemplates;
 		final String prefTabChar;
+		final boolean prefTabsOnlyForLeadingIndents;
 		
 		private final IPreferencesService preferenceService;
 		private final IScopeContext[] preferenceContexts;
@@ -143,8 +144,9 @@ public final class CIndenter {
 			prefIndentBracesForTypes= prefIndentBracesForTypes();
 			prefHasTemplates= hasTemplates();
 			prefTabChar= getCoreFormatterOption(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR);
+			prefTabsOnlyForLeadingIndents = prefTabsOnlyForLeadingIndents();
 		}
-		
+
 		private boolean prefUseTabs() {
 			return !CCorePlugin.SPACE.equals(getCoreFormatterOption(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR));
 		}
@@ -378,6 +380,11 @@ public final class CIndenter {
 		private boolean hasTemplates() {
 			return true;
 		}
+
+		private boolean prefTabsOnlyForLeadingIndents() {
+			return DefaultCodeFormatterConstants.TRUE.equals(
+					getCoreFormatterOption(DefaultCodeFormatterConstants.FORMATTER_USE_TABS_ONLY_FOR_LEADING_INDENTATIONS));
+		}
 	}
 
 	/** The document being scanned. */
@@ -500,7 +507,7 @@ public final class CIndenter {
 				// a special case has been detected.
 				IRegion line= fDocument.getLineInformationOfOffset(fAlign);
 				int lineOffset= line.getOffset();
-				return createIndent(lineOffset, fAlign, false);
+				return createIndent(lineOffset, fAlign, !fPrefs.prefTabsOnlyForLeadingIndents);
 			} catch (BadLocationException e) {
 				return null;
 			}
