@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2013 Wind River Systems, Inc. and others.
+ * Copyright (c) 2007, 2014 Wind River Systems, Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -289,7 +289,7 @@ public class IndexUI {
 		if (binding != null) {
 			IIndexName[] defs= index.findNames(binding, IIndex.FIND_DEFINITIONS | IIndex.SEARCH_ACROSS_LANGUAGE_BOUNDARIES);
 
-			ArrayList<ICElementHandle> result= new ArrayList<ICElementHandle>();
+			ArrayList<ICElementHandle> result= new ArrayList<>();
 			for (IIndexName in : defs) {
 				ICElementHandle definition= getCElementForName((ICProject) null, index, in);
 				if (definition != null) {
@@ -497,7 +497,8 @@ public class IndexUI {
 	/**
 	 * Searches for all specializations that depend on the definition of the given binding.
 	 */
-	public static List<? extends IBinding> findSpecializations(IIndex index, IBinding binding) throws CoreException {
+	public static List<? extends IBinding> findSpecializations(IIndex index, IBinding binding, IASTNode point)
+			throws CoreException {
 		List<IBinding> result= null;
 
 		// Check for instances of the given binding.
@@ -506,7 +507,7 @@ public class IndexUI {
 			for (ICPPTemplateInstance inst : instances) {
 				if (!ASTInternal.hasDeclaration(inst)) {
 					if (result == null)
-						result= new ArrayList<IBinding>(instances.length);
+						result= new ArrayList<>(instances.length);
 					result.add(inst);
 				}
 			}
@@ -515,8 +516,7 @@ public class IndexUI {
 		// Check for specializations of the owner.
 		IBinding owner = binding.getOwner();
 		if (owner != null) {
-			IASTNode point= null; // Instantiation of dependent expressions may not work.
-			List<? extends IBinding> specializations = findSpecializations(index, owner);
+			List<? extends IBinding> specializations = findSpecializations(index, owner, point);
 			for (IBinding specOwner : specializations) {
 				if (specOwner instanceof ICPPClassSpecialization) {
 					// Add the specialized member.
@@ -524,7 +524,7 @@ public class IndexUI {
 					specializedMember= index.adaptBinding(specializedMember);
 					if (specializedMember != null) {
 						if (result == null)
-							result= new ArrayList<IBinding>(specializations.size());
+							result= new ArrayList<>(specializations.size());
 						result.add(specializedMember);
 						// Also add instances of the specialized member.
 						if (specializedMember instanceof ICPPInstanceCache) {
