@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2011 PalmSource, Inc. and others.
+ * Copyright (c) 2006, 2014 PalmSource, Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -20,10 +20,14 @@
  * Anna Dushistova  (Mentor Graphics) - moved to org.eclipse.cdt.launch.remote.tabs
  * Anna Dushistova  (Mentor Graphics) - [318052] [remote launch] Properties are not saved/used
  * Anna Dushistova       (MontaVista) - [375067] [remote] Automated remote launch does not support project-less debug
+ * Dan Ungureanu          (Freescale) - [428367] [remote launch] Fix missing title for Properties dialog
+ * Alvaro Sanchez-Leon     (Ericsson) - [430313] [remote] Auto Remote Debug - Unable to download to folder
+ * Iulia Vasii            (Freescale) - [370768] new 'Edit...' button to access connection properties
  *******************************************************************************/
 package org.eclipse.cdt.launch.remote.tabs;
 
 import org.eclipse.cdt.dsf.gdb.internal.ui.launching.CMainTab;
+import org.eclipse.cdt.internal.launch.remote.Activator;
 import org.eclipse.cdt.internal.launch.remote.Messages;
 import org.eclipse.cdt.launch.remote.IRemoteConnectionConfigurationConstants;
 import org.eclipse.cdt.launch.remote.IRemoteConnectionHostConstants;
@@ -37,6 +41,7 @@ import org.eclipse.debug.core.ILaunchConfiguration;
 import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.preference.PreferenceDialog;
 import org.eclipse.jface.window.Window;
 import org.eclipse.rse.core.IRSESystemType;
 import org.eclipse.rse.core.RSECorePlugin;
@@ -60,6 +65,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.dialogs.PreferencesUtil;
 
 public class RemoteCDSFMainTab extends CMainTab {
 
@@ -73,8 +79,12 @@ public class RemoteCDSFMainTab extends CMainTab {
 	/* Defaults */
 	private static final String REMOTE_PATH_DEFAULT = EMPTY_STRING;
 	private static final boolean SKIP_DOWNLOAD_TO_REMOTE_DEFAULT = false;
+	
+	/* SystemConnectionPropertyPage id*/
+	private static final String SYSTEM_PAGE_ID = "org.eclipse.rse.SystemPropertyPage"; //$NON-NLS-1$
 
 	protected Button newRemoteConnectionButton;
+	protected Button editRemoteConnectionButton;
 	protected Button remoteConnectionPropertiesButton;
 	protected Button remoteBrowseButton;
 	protected Label connectionLabel;
@@ -119,7 +129,7 @@ public class RemoteCDSFMainTab extends CMainTab {
 				.getWorkbench()
 				.getHelpSystem()
 				.setHelp(getControl(),
-						"org.eclipse.rse.internal.remotecdt.launchgroup"); //$NON-NLS-1$
+						Activator.PLUGIN_ID + ".launchgroup"); //$NON-NLS-1$
 
 	}
 
@@ -154,7 +164,7 @@ public class RemoteCDSFMainTab extends CMainTab {
 	protected void createRemoteConnectionGroup(Composite parent, int colSpan) {
 		Composite projComp = new Composite(parent, SWT.NONE);
 		GridLayout projLayout = new GridLayout();
-		projLayout.numColumns = 4;
+		projLayout.numColumns = 5;
 		projLayout.marginHeight = 0;
 		projLayout.marginWidth = 0;
 		projComp.setLayout(projLayout);
@@ -176,7 +186,7 @@ public class RemoteCDSFMainTab extends CMainTab {
 
 			public void modifyText(ModifyEvent e) {
 				useDefaultsFromConnection();
-				updatePropertiesButton();
+				updateConnectionButtons();
 				setDirty(true);
 				updateLaunchConfigurationDialog();
 			}
@@ -193,6 +203,16 @@ public class RemoteCDSFMainTab extends CMainTab {
 				updateConnectionPulldown();
 			}
 		});
+		
+		editRemoteConnectionButton = createPushButton(projComp,
+				Messages.RemoteCMainTab_Edit, null);
+		editRemoteConnectionButton.addSelectionListener(new SelectionAdapter() {
+
+			@Override
+			public void widgetSelected(SelectionEvent evt) {
+				handleEditRemoteConnectionSelected();
+			}
+		});
 
 		remoteConnectionPropertiesButton = createPushButton(projComp,
 				Messages.RemoteCMainTab_Properties, null);
@@ -306,6 +326,17 @@ public class RemoteCDSFMainTab extends CMainTab {
 			// Ignore
 		}
 	}
+	
+	/**
+	 * Opens the <code>SystemConnectionPropertyPage</code> page for the selected connection.
+	 */
+	protected void handleEditRemoteConnectionSelected() {
+		IHost currentConnectionSelected = getCurrentConnection();
+		PreferenceDialog dialog = PreferencesUtil.createPropertyDialogOn(getControl().getShell(), currentConnectionSelected, SYSTEM_PAGE_ID, null, null);
+		if (dialog != null) {
+			dialog.open();
+		}
+	}
 
 	protected IHost getCurrentConnection() {
 		int currentSelection = connectionCombo.getSelectionIndex();
@@ -325,7 +356,18 @@ public class RemoteCDSFMainTab extends CMainTab {
 			Object retObj = dlg.getSelectedObject();
 			if (retObj instanceof IRemoteFile) {
 				IRemoteFile selectedFile = (IRemoteFile) retObj;
-				remoteProgText.setText(selectedFile.getAbsolutePath());
+				String absPath = selectedFile.getAbsolutePath();
+				if (selectedFile.isDirectory()) {
+					// The user selected a destination folder to upload the binary
+					// Append the Program name as the default file destination
+					IPath appPath = new Path(fProgText.getText().trim());
+					String lastSegment = appPath.lastSegment();
+					if (lastSegment != null && lastSegment.trim().length() > 0) {
+						IPath remotePath = new Path(selectedFile.getAbsolutePath()).append(lastSegment.trim());
+						absPath = remotePath.toPortableString();
+					}
+				}
+				remoteProgText.setText(absPath);
 			}
 
 		}
@@ -337,14 +379,21 @@ public class RemoteCDSFMainTab extends CMainTab {
 			boolean fbLocalHost;
 			private Button fSkipDownloadBtn;
 			private Text fWSRoot;
+			private String fDialogTitle;
 
 			public RemoteConnectionPropertyDialog(Shell parentShell,
 					String dialogTitle, IHost host) {
 				super(parentShell);
-				parentShell.setText(dialogTitle);
+				fDialogTitle = dialogTitle;
 				fHost = host;
 				fbLocalHost = fHost.getSystemType().isLocal();
 			}
+			
+			@Override
+			protected void configureShell(Shell shell) {
+				super.configureShell(shell);
+				shell.setText(fDialogTitle);
+			}
 
 			@Override
 			protected Control createDialogArea(Composite parent) {
@@ -443,23 +492,28 @@ public class RemoteCDSFMainTab extends CMainTab {
 		if (connections.length > 0) {
 			connectionCombo.select(connections.length - 1);
 		}
-		updatePropertiesButton();
+		updateConnectionButtons();
 	}
 
-	private void updatePropertiesButton() {
+	private void updateConnectionButtons() {
 		if ((remoteConnectionPropertiesButton == null)
 				|| remoteConnectionPropertiesButton.isDisposed()) {
 			return;
 		}
-		boolean bEnableProperties = false;
+		if ((editRemoteConnectionButton == null)
+				|| editRemoteConnectionButton.isDisposed()) {
+			return;
+		}
+		boolean bEnable = false;
 		IHost currentConnectionSelected = getCurrentConnection();
 		if (currentConnectionSelected != null) {
 			IRSESystemType sysType = currentConnectionSelected.getSystemType();
 			if (sysType != null && sysType.isEnabled() && !sysType.isLocal()) {
-				bEnableProperties = true;
+				bEnable = true;
 			}
 		}
-		remoteConnectionPropertiesButton.setEnabled(bEnableProperties);
+		remoteConnectionPropertiesButton.setEnabled(bEnable);
+		editRemoteConnectionButton.setEnabled(bEnable);
 	}
 
 	protected void updateTargetProgFromConfig(ILaunchConfiguration config) {
@@ -644,7 +698,7 @@ public class RemoteCDSFMainTab extends CMainTab {
 
 		updateTargetProgFromConfig(config);
 		updateSkipDownloadFromConfig(config);
-		updatePropertiesButton();
+		updateConnectionButtons();
 		isInitializing = false;
 	}
 
