@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2014 Red Hat, Inc.
+ * Copyright (c) 2013, 2015 Red Hat, Inc.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *    Red Hat Inc. - initial API and implementation
+ *    Marc Khouzam (Ericsson) - Update for remote debugging support (bug 450080)
  *******************************************************************************/
 package org.eclipse.cdt.debug.application;
 
@@ -22,6 +23,7 @@ import org.eclipse.cdt.debug.core.ICDTLaunchConfigurationConstants;
 import org.eclipse.cdt.internal.debug.application.DebugAttachedExecutable;
 import org.eclipse.cdt.internal.debug.application.DebugCoreFile;
 import org.eclipse.cdt.internal.debug.application.DebugExecutable;
+import org.eclipse.cdt.internal.debug.application.DebugRemoteExecutable;
 import org.eclipse.cdt.internal.debug.application.JobContainer;
 import org.eclipse.cdt.utils.spawner.ProcessFactory;
 import org.eclipse.core.resources.ResourcesPlugin;
@@ -57,9 +59,6 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 	private ILaunchConfiguration config;
 
 	private class StartupException extends FileNotFoundException {
-		/**
-		 * 
-		 */
 		private static final long serialVersionUID = 1L;
 
 		public StartupException(String s) {
@@ -87,17 +86,6 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 		configurer.setTitle(Messages.Debugger_Title);
 	}
 
-//	private class CWDTracker implements IWorkingDirectoryTracker {
-//
-//		@Override
-//		public URI getWorkingDirectoryURI() {
-//			return null;
-//		}
-//
-//	}
-	
-
-
 	@Override
 	public void postWindowCreate() {
 		super.postWindowCreate();
@@ -153,31 +141,56 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 			String corefile = null;
 			String buildLog = null;
 			String arguments = null;
+			String remoteAddress = null;
+			String remotePort = null;
+			String pid = null;
 			String[] args = Platform.getCommandLineArgs();
-//			System.out.println("program args length is " + args.length);
+
 			try {
 				for (int i = 0; i < args.length; ++i) {
-//									System.out.println("arg <" + i + "> is " + args[i]);
-					if ("-application".equals(args[i]))
+					if ("-application".equals(args[i])) //$NON-NLS-1$
 						i++; // ignore the application specifier
-					else if ("-product".equals(args[i]))
+					else if ("-product".equals(args[i])) //$NON-NLS-1$
 						i++; // ignore the product specifier
-					else if ("-b".equals(args[i])) {
+					else if ("-b".equals(args[i])) { //$NON-NLS-1$
 						++i;
 						if (i < args.length)
 							buildLog = args[i];
 					}
-					else if ("-a".equals(args[i])) {
+					else if ("-a".equals(args[i])) { //$NON-NLS-1$
 						attachExecutable = true;
+						// Make sure 'executable' is still null in case we are dealing with a remote
+						// session that is also an attach, as the -r flag could have been set first
+						executable = null;
+						
+						// Check for optional pid
+						if (i + 1 < args.length) {
+							if (!args[i+1].startsWith("-")) { //$NON-NLS-1$
+								++i;
+								pid = args[i];
+							}
+						}
 					}
-					else if ("-c".equals(args[i])) {
+					else if ("-c".equals(args[i])) { //$NON-NLS-1$
 						++i;
-						corefile = "";
-						executable = "";
+						corefile = ""; //$NON-NLS-1$
+						executable = ""; //$NON-NLS-1$
 						if (i < args.length)
 							corefile = args[i];
 					}
-					else if ("-e".equals(args[i])) {
+					else if ("-r".equals(args[i])) { //$NON-NLS-1$
+						++i;
+						remoteAddress = ""; //$NON-NLS-1$
+						if (!attachExecutable) executable = ""; //$NON-NLS-1$
+						if (i < args.length) {
+							String[] params = args[i].split(":"); //$NON-NLS-1$
+							if (params.length == 2) {
+								remoteAddress = params[0];
+								remotePort = params[1];
+							}
+						}
+					}
+					else if ("-e".equals(args[i])) { //$NON-NLS-1$
 						++i;
 						if (i < args.length)
 							executable = findExecutable(args[i]);
@@ -187,7 +200,7 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						if (i < args.length)
 							argBuffer.append(args[i++]);
 						while (i < args.length) {
-							argBuffer.append(" ");
+							argBuffer.append(" "); //$NON-NLS-1$
 							argBuffer.append(args[i++]);
 						}
 						arguments = argBuffer.toString();
@@ -202,8 +215,8 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 					}
 					File coreFile = new File(corefile);
 					corefile = coreFile.getCanonicalPath();
-					if (executable == null || !executableFile.exists() || !coreFile.exists()) {
-						final CoreFileInfo info = new CoreFileInfo("", "", ""); //$NON-NLS-1$ $NON-NLS-2$ $NON-NLS-3$
+					if (executableFile == null || !executableFile.exists() || !coreFile.exists()) {
+						final CoreFileInfo info = new CoreFileInfo("", "", ""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ $NON-NLS-2$ $NON-NLS-3$
 						final IStatus errorStatus = new Status(IStatus.ERROR, Activator.PLUGIN_ID, 0, 
 								Messages.GdbDebugNewExecutableCommand_Binary_file_does_not_exist, null);
 						final String executablePath = executable;
@@ -229,7 +242,7 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 							}
 						});
 						// Check and see if we failed above and if so, quit
-						if (info.getHostPath().equals("")) {
+						if (info.getHostPath().equals("")) { //$NON-NLS-1$
 							monitor.done();
 							// throw internal exception which will be caught below
 							throw new StartupException(errorStatus.getMessage());
@@ -237,6 +250,62 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						executable = info.getHostPath();
 						corefile = info.getCoreFilePath();
 					}
+				} else if (remoteAddress != null) {
+					// Verify what we can about the port, address and executable.
+					File executableFile = null;
+					if (executable != null) {
+						executableFile = new File(executable);
+						executable = executableFile.getCanonicalPath();
+					}
+					
+					Integer port = null;
+					try {
+						port = Integer.parseInt(remotePort);
+					} catch (NumberFormatException e) {
+						port = null;
+					}
+					
+					if ((!attachExecutable && (executableFile == null || !executableFile.exists())) ||
+							remoteAddress.length() == 0 || port == null) {
+						final RemoteExecutableInfo[] info = new RemoteExecutableInfo[1];
+						final IStatus errorStatus = new Status(IStatus.ERROR, Activator.PLUGIN_ID, 0, 
+								Messages.GdbDebugNewExecutableCommand_Binary_file_does_not_exist, null);
+						final String executablePath = executable;
+						final String addressStr = remoteAddress;
+						final String portStr = remotePort;
+						final String buildLogPath = buildLog;
+						final boolean attach = attachExecutable;
+						
+						Display.getDefault().syncExec(new Runnable() {
+
+							@Override
+							public void run() {
+
+								RemoteExecutableDialog dialog = new RemoteExecutableDialog(getWindowConfigurer().getWindow().getShell(),
+										executablePath, buildLogPath, addressStr, portStr, attach);
+								dialog.setBlockOnOpen(true);
+								if (dialog.open() == IDialogConstants.OK_ID) {
+									info[0] = dialog.getExecutableInfo();
+								} else {
+									info[0] = null;
+									ErrorDialog.openError(null,
+											Messages.DebuggerInitializingProblem, null, errorStatus,
+											IStatus.ERROR | IStatus.WARNING);
+								}
+							}
+						});
+						// Check and see if we failed above and if so, quit
+						if (info[0] == null) {
+							monitor.done();
+							// throw internal exception which will be caught below
+							throw new StartupException(errorStatus.getMessage());
+						}
+						executable = info[0].getHostPath();
+						buildLog = info[0].getBuildLog();
+						remoteAddress = info[0].getAddress();
+						remotePort = info[0].getPort();
+						attachExecutable = info[0].isAttach();
+					}
 				} else if (executable != null) {
 					File executableFile = new File(executable);
 					executable = executableFile.getCanonicalPath();
@@ -245,8 +314,8 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						buildLogFile = new File(buildLog);
 						buildLog = buildLogFile.getCanonicalPath();
 					}
-					if (!executableFile.exists() || (buildLog != null && !buildLogFile.exists())) {
-						final NewExecutableInfo info = new NewExecutableInfo("", "", "", ""); //$NON-NLS-1$ $NON-NLS-2$ $NON-NLS-3$
+					if (!executableFile.exists() || (buildLogFile != null && !buildLogFile.exists())) {
+						final NewExecutableInfo info = new NewExecutableInfo("", "", "", ""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ $NON-NLS-2$ $NON-NLS-3$
 						final IStatus errorStatus = new Status(IStatus.ERROR, Activator.PLUGIN_ID, 0, 
 								Messages.GdbDebugNewExecutableCommand_Binary_file_does_not_exist, null);
 						final String executablePath = executable;
@@ -273,7 +342,7 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 							}
 						});
 						// Check and see if we failed above and if so, quit
-						if (info.getHostPath().equals("")) {
+						if (info.getHostPath().equals("")) { //$NON-NLS-1$
 							monitor.done();
 							// throw internal exception which will be caught below
 							throw new StartupException(errorStatus.getMessage());
@@ -283,8 +352,11 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 					}
 				}
 				monitor.worked(1);
-				if (attachExecutable) {
-					config = DebugAttachedExecutable.createLaunchConfig(monitor, buildLog);
+				if (remoteAddress != null && remoteAddress.length() > 0 && 
+						remotePort != null && remotePort.length() > 0) {
+					config = DebugRemoteExecutable.createLaunchConfig(monitor, buildLog, executable, remoteAddress, remotePort, attachExecutable);
+				} else if (attachExecutable) {
+					config = DebugAttachedExecutable.createLaunchConfig(monitor, buildLog, pid);
 				} else if (corefile != null && corefile.length() > 0) {
 					config = DebugCoreFile.createLaunchConfig(monitor, buildLog, executable, corefile);
 				} else if (executable != null && executable.length() > 0) {
@@ -296,15 +368,15 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 					String memento = ResourcesPlugin.getWorkspace().getRoot().getPersistentProperty(new QualifiedName(STANDALONE_QUALIFIER, LAST_LAUNCH));
 					if (memento != null)
 						config = DebugExecutable.getLaunchManager().getLaunchConfiguration(memento);
-					String oldExecutable = "";
-					String oldArguments = "";
-					String oldBuildLog = "";
+					String oldExecutable = ""; //$NON-NLS-1$
+					String oldArguments = ""; //$NON-NLS-1$
+					String oldBuildLog = ""; //$NON-NLS-1$
 					if (config != null) {
 						oldExecutable = config.getAttribute(ICDTLaunchConfigurationConstants.ATTR_PROGRAM_NAME, ""); //$NON-NLS-1$
 						oldArguments = config.getAttribute(ICDTLaunchConfigurationConstants.ATTR_PROGRAM_ARGUMENTS, ""); //$NON-NLS-1$
 						oldBuildLog = config.getAttribute(ICDTStandaloneDebugLaunchConstants.BUILD_LOG_LOCATION, ""); //$NON-NLS-1$
 					}
-					final NewExecutableInfo info = new NewExecutableInfo("", "", "", ""); //$NON-NLS-1$ $NON-NLS-2$ $NON-NLS-3$
+					final NewExecutableInfo info = new NewExecutableInfo("", "", "", ""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ $NON-NLS-2$ $NON-NLS-3$
 					final IStatus errorStatus = new Status(IStatus.WARNING, Activator.PLUGIN_ID, 0, 
 							Messages.GdbDebugNewExecutableCommand_Binary_file_does_not_exist, null);
 					final String executablePath = oldExecutable;
@@ -333,7 +405,7 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						}
 					});
 					// Check and see if we failed above and if so, quit
-					if (info.getHostPath().equals("")) {
+					if (info.getHostPath().equals("")) { //$NON-NLS-1$
 						monitor.done();
 						// throw internal exception which will be caught below
 						throw new StartupException(errorStatus.getMessage());
@@ -358,21 +430,18 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 					monitor.worked(7);
 				}
 				if (config != null) {
-//					System.out.println("about to add job change listener");
 					final JobContainer LaunchJobs = new JobContainer();
 					Job.getJobManager().addJobChangeListener(new JobChangeAdapter() {
 
 						@Override
 						public void scheduled(IJobChangeEvent event) {
 							Job job = event.getJob();
-//							System.out.println("Job name is " + job.getName());
 							if (job.getName().contains(config.getName()))
 								LaunchJobs.setLaunchJob(job);
 						}
 
 						@Override
 						public void done(IJobChangeEvent event) {
-//							System.out.println("Job " + event.getJob().getName() + " is done");
 						}
 					});
 					monitor.subTask(Messages.LaunchingConfig);
@@ -381,7 +450,6 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						@Override
 						public void run() {
 							DebugUITools.launch(config, ILaunchManager.DEBUG_MODE);
-//							System.out.println("about to join " + LaunchJobs.getLaunchJob());
 						}
 					});
 					if (LaunchJobs.getLaunchJob() != null) {
@@ -394,20 +462,15 @@ public class ApplicationWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {
 						}
 					}
 				}
-//				System.out.println("end");
 			} catch (InterruptedException e) {
-//				System.out.println("Interrupted exception");
 				throw e; // rethrow exception
 			} catch (CoreException e) {
-//				System.out.println("Core Exception");
 				e.printStackTrace();
 			} catch (StartupException e) {
 				// do nothing..just quit
 			} catch (Exception e) {
-//				System.out.println("Exception");
 				e.printStackTrace();
 			} finally {
-//				System.out.println("Finally");
 				monitor.done();
 			}
 		}
