@@ -12,17 +12,18 @@ package org.eclipse.cdt.debug.internal.core.sourcelookup;
 
 import java.io.IOException;
 import java.io.StringReader;
-import com.ibm.icu.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
+
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.TransformerException;
+
 import org.eclipse.cdt.debug.core.CDebugCorePlugin;
 import org.eclipse.cdt.debug.core.CDebugUtils;
 import org.eclipse.cdt.debug.core.model.ICStackFrame;
@@ -52,6 +53,8 @@ import org.w3c.dom.NodeList;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 
+import com.ibm.icu.text.MessageFormat;
+
 /**
  * Default source locator.
  */
@@ -384,7 +387,7 @@ public class CSourceLocator implements ICSourceLocator, IPersistableSourceLocato
 					try {
 						clazz = bundle.loadClass(className);
 					} catch (ClassNotFoundException e) {
-						CDebugCorePlugin.log(MessageFormat.format("Unable to restore source location - class not found {0}", new String[]{ className })); //$NON-NLS-1$
+						CDebugCorePlugin.log(MessageFormat.format("Unable to restore source location - class not found {0}", new Object[]{ className })); //$NON-NLS-1$
 						continue;
 					}
 					ICSourceLocation location = null;
@@ -430,7 +433,7 @@ public class CSourceLocator implements ICSourceLocator, IPersistableSourceLocato
 					try {
 						clazz = bundle.loadClass(className);
 					} catch (ClassNotFoundException e) {
-						CDebugCorePlugin.log(MessageFormat.format("Unable to restore source location - class not found {0}", new String[]{ className })); //$NON-NLS-1$
+						CDebugCorePlugin.log(MessageFormat.format("Unable to restore source location - class not found {0}", new Object[]{ className })); //$NON-NLS-1$
 						continue;
 					}
 					ICSourceLocation location = null;
