@@ -8,6 +8,7 @@
  * Contributors:
  * Mentor Graphics - Initial API and implementation
  * Marc Khouzam (Ericsson) - Don't allow to set two bps at same line (bug 432503)
+ * Teodor Madan (Freescale) - Do not create multiple watchpoints /method breakpoints at same location ( 445375 )
  *******************************************************************************/
 
 package org.eclipse.cdt.debug.ui.breakpoints;
@@ -39,6 +40,7 @@ import org.eclipse.cdt.debug.internal.ui.actions.ActionMessages;
 import org.eclipse.cdt.debug.internal.ui.actions.breakpoints.EnableDisableBreakpointRulerAction;
 import org.eclipse.cdt.debug.internal.ui.breakpoints.CBreakpointContext;
 import org.eclipse.cdt.debug.ui.CDebugUIPlugin;
+import org.eclipse.cdt.internal.ui.util.EditorUtility;
 import org.eclipse.cdt.internal.ui.util.ExternalEditorInput;
 import org.eclipse.cdt.ui.CDTUITools;
 import org.eclipse.core.filesystem.URIUtil;
@@ -183,8 +185,7 @@ abstract public class AbstractToggleBreakpointAdapter
 	
 	@Override
 	public boolean canCreateWatchpointsInteractive(IWorkbenchPart part, ISelection selection) {
-	    // Gather all input from user if needed.
-	    return true;
+	    return canToggleWatchpoints(part, selection) && !hasWatchpoint(part, selection);
 	}
 	
 	@Override
@@ -228,7 +229,7 @@ abstract public class AbstractToggleBreakpointAdapter
 
 	@Override
 	public boolean canCreateFunctionBreakpointInteractive(IWorkbenchPart part, ISelection selection) {
-	    return true;
+	    return canToggleMethodBreakpoints(part, selection) && !hasMethodBreakpoints(part, selection);
 	}
 	
 	@Override
@@ -255,6 +256,40 @@ abstract public class AbstractToggleBreakpointAdapter
     	return false;
     }
 
+    private boolean hasWatchpoint(IWorkbenchPart part, ISelection selection) {
+    	ICElement element = getCElementFromSelection( part, selection );
+    	if (element instanceof IVariable) {
+    		IVariable variable = (IVariable) element;
+    		String sourceHandle = getSourceHandle(variable );
+    		IResource resource = getElementResource(variable);
+    		String expression = getVariableName(variable);		
+    		try {
+    			return null != findWatchpoint(sourceHandle, resource, expression);
+    		} catch (CoreException e) {
+    			DebugPlugin.log(e);
+    		}
+    	}
+    	return false;
+    }
+
+    private boolean hasMethodBreakpoints(IWorkbenchPart part, ISelection selection) {
+    	ICElement element = getCElementFromSelection( part, selection );
+    	if ( element instanceof IFunction || element instanceof IMethod ) {
+    		IDeclaration declaration =  (IDeclaration) element;
+    		String sourceHandle = getSourceHandle(declaration);
+    		IResource resource = getElementResource(declaration);
+    		String functionName = (declaration instanceof IFunction) ? 
+    				getFunctionName((IFunction) declaration) 
+    				: getMethodName((IMethod) declaration);
+    				try {
+    					return null != findFunctionBreakpoint(sourceHandle, resource, functionName);
+    				} catch (CoreException e) {
+    					DebugPlugin.log(e);
+    				}
+    	}
+    	return false;
+    }
+
     /**
      * Updates the breakpoint for given part and selection.  
      * Depending on the flags and on whether a breakpoint exists, this method 
@@ -606,7 +641,8 @@ abstract public class AbstractToggleBreakpointAdapter
         return null;
 	}
 
-    protected ICWatchpointTarget getWatchpointTarget( IWorkbenchPart part, ISelection selection ) {
+    @SuppressWarnings("deprecation")
+	protected ICWatchpointTarget getWatchpointTarget( IWorkbenchPart part, ISelection selection ) {
         if (selection != null && selection instanceof IStructuredSelection && !selection.isEmpty()) {
             Object obj = ((IStructuredSelection)selection).getFirstElement();
             if (obj != null) {
@@ -646,31 +682,37 @@ abstract public class AbstractToggleBreakpointAdapter
 
 	/**
 	 * Returns the resource being edited in the given workbench part. 
-	 * @param part Workbench part to checm.
+	 * @param part Workbench part to check.
 	 * @return Resource being edited.
 	 */
 	protected static IResource getResource( IWorkbenchPart part ) {
 		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
 		if ( part instanceof IEditorPart ) {
 			IEditorInput editorInput = ((IEditorPart)part).getEditorInput();
-			IResource resource = null;
-			if ( editorInput instanceof IFileEditorInput ) {
-				resource = ((IFileEditorInput)editorInput).getFile();
-			}
-			else if ( editorInput instanceof ExternalEditorInput ) {
-				resource = ((ExternalEditorInput)editorInput).getMarkerResource();
-			}
-			if ( resource != null )
-				return resource;
-			/* This file is not in a project, let default case handle it */
-			ILocationProvider provider = (ILocationProvider)editorInput.getAdapter( ILocationProvider.class );
-			if ( provider != null ) {
-				IPath location = provider.getPath( editorInput );
-				if ( location != null ) {
-					IFile[] files = root.findFilesForLocationURI( URIUtil.toURI( location ) );
-					if ( files.length > 0 && files[0].isAccessible())
-						return files[0];
-				}
+			return getResource(editorInput);
+		}
+		return root;
+	}
+
+	private static IResource getResource(IEditorInput editorInput) {
+		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
+		IResource resource = null;
+		if ( editorInput instanceof IFileEditorInput ) {
+			resource = ((IFileEditorInput)editorInput).getFile();
+		}
+		else if ( editorInput instanceof ExternalEditorInput ) {
+			resource = ((ExternalEditorInput)editorInput).getMarkerResource();
+		}
+		if ( resource != null )
+			return resource;
+		/* This file is not in a project, let default case handle it */
+		ILocationProvider provider = (ILocationProvider)editorInput.getAdapter( ILocationProvider.class );
+		if ( provider != null ) {
+			IPath location = provider.getPath( editorInput );
+			if ( location != null ) {
+				IFile[] files = root.findFilesForLocationURI( URIUtil.toURI( location ) );
+				if ( files.length > 0 && files[0].isAccessible())
+					return files[0];
 			}
 		}
 		return root;
@@ -691,8 +733,25 @@ abstract public class AbstractToggleBreakpointAdapter
 		return ""; //$NON-NLS-1$
 	}
 
+	/**
+	 * Returns the resource file containing the C model element. 
+	 * 
+	 * @param declaration model element
+	 * @return resource for c model element. Cannot be null, will return workspace root when no resource file can be found.  
+	 */
+	
 	protected IResource getElementResource( IDeclaration declaration ) {
-		return declaration.getUnderlyingResource();
+		IResource resource = declaration.getUnderlyingResource();
+		if (resource != null)
+			return resource;
+		
+		try {
+			IEditorInput editorInput = EditorUtility.getEditorInput(declaration);
+			return getResource(editorInput);
+		} catch (CModelException e) {
+			DebugPlugin.log(e);
+		}
+		return ResourcesPlugin.getWorkspace().getRoot();
 	}
 
 	private String getFunctionName( IFunction function ) {
