@@ -62,9 +62,6 @@ import org.eclipse.swt.widgets.Label;
 
 public class GdbThreadFilterEditor {
 
-    /**
-     * Comment for ThreadFilterEditor.
-     */
     public class CheckHandler implements ICheckStateListener {
 
         /*
@@ -123,17 +120,10 @@ public class GdbThreadFilterEditor {
         }
     }
 
-    /**
-     * Comment for ThreadFilterEditor.
-     */
     public class ThreadFilterContentProvider implements ITreeContentProvider {
 
-        /**
-         * Constructor for ThreadFilterContentProvider.
-         */
         public ThreadFilterContentProvider() {
             super();
-            // TODO Auto-generated constructor stub
         }
 
         /*
@@ -248,9 +238,6 @@ public class GdbThreadFilterEditor {
 
     private CheckHandler fCheckHandler;
 
-    /**
-     * Constructor for ThreadFilterEditor.
-     */
     public GdbThreadFilterEditor(Composite parent, CBreakpointGdbThreadFilterPage page) {
         fPage = page;
         fContentProvider = new ThreadFilterContentProvider();
@@ -528,18 +515,21 @@ public class GdbThreadFilterEditor {
                         @Override
                         protected void handleSuccess() {
                             final StringBuilder builder = new StringBuilder(Messages.GdbThreadFilterEditor_Thread);
-                            builder.append("["); //$NON-NLS-1$
+                            builder.append(" #"); //$NON-NLS-1$
                             builder.append(((IMIExecutionDMContext)thread).getThreadId());
-                            builder.append("] "); //$NON-NLS-1$
+
+                            String threadName = getData().getName();
+                            if (threadName != null) {
+                            	builder.append(" ["); //$NON-NLS-1$
+                            	builder.append(threadName);
+                            	builder.append("] "); //$NON-NLS-1$
+                            }
+
                             String threadId = getData().getId();
                             if (threadId != null) {
                             	builder.append(threadId);
                             }
-                            String threadName = getData().getName();
-                            if (threadName != null) {
-                            	builder.append(threadName);
-                            }
-
+                            
                             rm.setData(builder.toString());
                             rm.done();
                         }
