@@ -9,6 +9,7 @@
  *     Freescale Semiconductor - initial API and implementation
  *     Jens Elmenthaler (Verigy) - Added Full GDB pretty-printing support (bug 302121)
  *     Marc Khouzam (Ericsson) - Add support disable "View Memory" action (bug 418710)
+ *     Marc Khouzam (Ericsson) - Turn off "watch" action for return values of methods (bug 341731)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.gdb.internal.ui.viewmodel;
 
@@ -48,6 +49,7 @@ import org.eclipse.debug.internal.ui.viewers.model.provisional.IChildrenCountUpd
 import org.eclipse.debug.internal.ui.viewers.model.provisional.IChildrenUpdate;
 import org.eclipse.debug.internal.ui.viewers.model.provisional.IHasChildrenUpdate;
 import org.eclipse.debug.internal.ui.viewers.model.provisional.IModelDelta;
+import org.eclipse.debug.ui.actions.IWatchExpressionFactoryAdapter2;
 import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.TreePath;
 
@@ -194,6 +196,15 @@ public class GdbVariableVMNode extends VariableVMNode {
 			}
 			return super.canViewInMemory();
 		}
+        
+        @SuppressWarnings({ "unchecked", "rawtypes" })
+		@Override
+        public Object getAdapter(Class adapter) {
+        	if (adapter.isAssignableFrom(IWatchExpressionFactoryAdapter2.class)) {
+                return fGdbVariableExpressionFactory;
+        	}
+        	return super.getAdapter(adapter);
+        }
 	};
 	
 	private static boolean isConvenienceVariable(String expr) {
@@ -229,6 +240,25 @@ public class GdbVariableVMNode extends VariableVMNode {
 		return false;
 	}
 
+	/**
+	 * A factory to control the "Watch" action for GDB variables.
+	 */
+    protected class GdbVariableExpressionFactory extends VariableExpressionFactory {
+    	@Override
+    	public boolean canCreateWatchExpression(Object element) {
+    		if (element instanceof VariableExpressionVMC) {
+    			String expression = ((VariableExpressionVMC)element).getExpression();
+    			if (isConvenienceVariable(expression)) {
+    				return false;
+    			}
+    		}
+    		
+    		return super.canCreateWatchExpression(element);
+    	}
+    }
+    
+    final protected VariableExpressionFactory fGdbVariableExpressionFactory = new GdbVariableExpressionFactory();
+
 	/**
 	 * The special context representing more children to be available.
 	 * 
