@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2013 Texas Instruments, Freescale Semiconductor and others.
+ * Copyright (c) 2010, 2014 Texas Instruments, Freescale Semiconductor and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -8,16 +8,22 @@
  * Contributors:
  *     Texas Instruments, Freescale Semiconductor - initial API and implementation
  *     Alvaro Sanchez-Leon (Ericsson AB) - Each memory context needs a different MemoryRetrieval (Bug 250323)
+ *     Alvaro Sanchez-Leon (Ericsson AB) - [Memory] Support 16 bit addressable size (Bug 426730)
+ *     Anders Dahlberg (Ericsson)  - Need additional API to extend support for memory spaces (Bug 431627)
+ *     Alvaro Sanchez-Leon (Ericsson AB)  - Need additional API to extend support for memory spaces (Bug 431627)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.gdb.internal.memory;
 
 import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.RejectedExecutionException;
 
 import org.eclipse.cdt.debug.core.model.provisional.IMemorySpaceAwareMemoryBlock;
 import org.eclipse.cdt.debug.core.model.provisional.IMemorySpaceAwareMemoryBlockRetrieval;
 import org.eclipse.cdt.dsf.concurrent.DataRequestMonitor;
+import org.eclipse.cdt.dsf.concurrent.DsfRunnable;
 import org.eclipse.cdt.dsf.concurrent.Query;
 import org.eclipse.cdt.dsf.datamodel.DMContexts;
 import org.eclipse.cdt.dsf.datamodel.IDMContext;
@@ -25,7 +31,12 @@ import org.eclipse.cdt.dsf.debug.model.DsfMemoryBlock;
 import org.eclipse.cdt.dsf.debug.model.DsfMemoryBlockRetrieval;
 import org.eclipse.cdt.dsf.debug.service.IMemory.IMemoryDMContext;
 import org.eclipse.cdt.dsf.debug.service.IMemorySpaces;
+import org.eclipse.cdt.dsf.debug.service.IMemorySpaces.IMemorySpaceDMContext;
+import org.eclipse.cdt.dsf.debug.service.IMemorySpaces2;
 import org.eclipse.cdt.dsf.gdb.internal.GdbPlugin;
+import org.eclipse.cdt.dsf.gdb.internal.memory.GdbMemoryBlock.MemorySpaceDMContext;
+import org.eclipse.cdt.dsf.gdb.service.IGDBMemory;
+import org.eclipse.cdt.dsf.gdb.service.IGDBMemory2;
 import org.eclipse.cdt.dsf.service.DsfServices;
 import org.eclipse.cdt.dsf.service.DsfSession;
 import org.eclipse.core.runtime.CoreException;
@@ -45,6 +56,8 @@ import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
+import com.ibm.icu.text.MessageFormat;
+
 /**
  * A specialization of the DSF memory block retrieval implementation supporting
  * memory spaces. The memory space support is provisional, thus this class is
@@ -55,7 +68,7 @@ import org.w3c.dom.NodeList;
 public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 		IMemorySpaceAwareMemoryBlockRetrieval {
 
-    private final ServiceTracker  fMemorySpaceServiceTracker;
+    private final ServiceTracker<IMemorySpaces, IMemorySpaces>  fMemorySpaceServiceTracker;
 
 	// No need to use the constants in our base class. Serializing and
 	// recreating the blocks is done entirely by us
@@ -82,7 +95,7 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 		// Create a tracker for the memory spaces service
  		String filter = DsfServices.createServiceFilter(IMemorySpaces.class, session.getId());
  		try {
-			fMemorySpaceServiceTracker = new ServiceTracker(
+			fMemorySpaceServiceTracker = new ServiceTracker<>(
 					bundle,	bundle.createFilter(filter), null);
 		} catch (InvalidSyntaxException e) {
 			throw new DebugException(new Status(IStatus.ERROR,
@@ -98,11 +111,26 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 	 */
 	@Override
 	public IMemoryBlockExtension getExtendedMemoryBlock(String expression, Object context) throws DebugException {
-		// Technically, we don't need to override this method. Letting our base
-		// class create a DsfMemoryBlock would work just fine. But, for the
-		// sake of consistency, lets have this retrieval class always return a
-		// GdbMemoryBlock.
-		return getMemoryBlock(expression, context, null);
+		
+		String memorySpaceID = null;
+		
+		// Determine if the expression has memory space information
+		IDMContext dmc = null;
+		if (context instanceof IDMContext) {
+			dmc = (IDMContext) context;
+		} else {
+	        if (context instanceof IAdaptable) {
+	        	dmc = (IDMContext)((IAdaptable)context).getAdapter(IDMContext.class);
+	        }
+		}
+		
+		if (dmc != null) {
+			DecodeResult result = decodeMemorySpaceExpression(dmc, expression);
+			expression = result.getExpression();
+			memorySpaceID = result.getMemorySpaceId();
+		}
+		
+		return getMemoryBlock(expression, context, memorySpaceID);
 	}
 	
 	/* (non-Javadoc)
@@ -124,6 +152,17 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
             return null;
         }
         
+        //Adjust the memory context to use memory spaces when available
+        if (memoryDmc instanceof IMemorySpaceDMContext) {
+        	// The memory space ids should match
+        	assert(memorySpaceID != null);
+        	assert(memorySpaceID.equals(((IMemorySpaceDMContext)memoryDmc).getMemorySpaceId()));
+        } else {
+            if (memorySpaceID != null && memorySpaceID.length() > 0) {
+            	memoryDmc = new MemorySpaceDMContext(getSession().getId(), memorySpaceID, memoryDmc);
+            }        	
+        }
+        
 		// The block start address (supports 64-bit processors)
 		BigInteger blockAddress;
 
@@ -169,6 +208,14 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 			}
 		}
 
+		// check for block address exceeding maximum allowed address value
+		int addressSize = getAddressSize(memoryDmc);
+		BigInteger endAddress = BigInteger.ONE.shiftLeft(addressSize*8).subtract(BigInteger.ONE);
+		if (endAddress.compareTo(blockAddress) < 0) {
+			throw new DebugException(new Status(IStatus.ERROR, GdbPlugin.PLUGIN_ID, -1, 
+					MessageFormat.format(Messages.Err_ExceedsMaxAddress, expression, endAddress.toString(16)), null));
+		}
+		
 		/*
 		 * At this point, we only resolved the requested memory block
 		 * start address and we have no idea of the block's length.
@@ -181,7 +228,7 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 		 * same memory block, a trip to the target could result. However,
 		 * the memory request cache should save the day.
 		 */
-		return new GdbMemoryBlock(this, memoryDmc, getModelId(), expression, blockAddress, getAddressableSize(), 0, memorySpaceID);
+		return new GdbMemoryBlock(this, memoryDmc, getModelId(), expression, blockAddress, getAddressableSize(memoryDmc), 0, memorySpaceID);
 	}
 
 	/*
@@ -190,18 +237,19 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 	 */
 	@Override
 	public void getMemorySpaces(final Object context, final GetMemorySpacesRequest request) {
-		Query<String[]> query = new Query<String[]>() {
+        try {
+        	getExecutor().execute(new DsfRunnable() {
 			@Override
-			protected void execute(final DataRequestMonitor<String[]> drm) {
+			public void run() {
 		        IDMContext dmc = null;
 		        if (context instanceof IAdaptable) {
 		        	dmc = (IDMContext)((IAdaptable)context).getAdapter(IDMContext.class);
 		            if (dmc != null) {
-		        		IMemorySpaces service = (IMemorySpaces)fMemorySpaceServiceTracker.getService();
+		        		IMemorySpaces service = fMemorySpaceServiceTracker.getService();
 		                if (service != null) {
 		        			service.getMemorySpaces(
 		        				dmc, 
-		        				new DataRequestMonitor<String[]>(getExecutor(), drm) {
+		        				new DataRequestMonitor<String[]>(getExecutor(), null) {
 			            			@Override
 			            			protected void handleCompleted() {
 			            				// Store the result
@@ -212,20 +260,22 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 			            					request.setStatus(getStatus());
 			            				}
 		            					request.done();
-			            				drm.done(); // don't bother with status; we don't check it below
 			            			}
 		        				});
-		                }
-		                else {
-		                	request.setStatus(new Status(IStatus.ERROR,	GdbPlugin.PLUGIN_ID, DebugException.INTERNAL_ERROR, Messages.Err_MemoryServiceNotAvailable, null));
-		                	request.done();
-            				drm.done();		                	
+		        			return;
 		                }
 		            }
 		        }
+		        
+		        // If we get here, something didn't work as expected
+		        request.setStatus(new Status(IStatus.ERROR,	GdbPlugin.PLUGIN_ID, DebugException.INTERNAL_ERROR, "Unable to get memory spaces", null)); //$NON-NLS-1$
+                request.done();
 			}
-		};
-		getExecutor().execute(query);
+		});
+        } catch (RejectedExecutionException e) {
+	        request.setStatus(new Status(IStatus.ERROR,	GdbPlugin.PLUGIN_ID, DebugException.INTERNAL_ERROR, "Unable to get memory spaces", null)); //$NON-NLS-1$
+        	request.done();
+        }
 	}
 	
 	/* (non-Javadoc)
@@ -234,7 +284,7 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 	@Override
 	public String encodeAddress(String expression, String memorySpaceID) {
 		String result = null;
-    	IMemorySpaces service = (IMemorySpaces)fMemorySpaceServiceTracker.getService();
+    	IMemorySpaces service = fMemorySpaceServiceTracker.getService();
         if (service != null) {
         	// the service can tell us to use our default encoding by returning null
 			result = service.encodeAddress(expression, memorySpaceID);
@@ -251,7 +301,7 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 	 */
 	@Override
 	public DecodeResult decodeAddress(String str) throws CoreException {
-    	IMemorySpaces service = (IMemorySpaces)fMemorySpaceServiceTracker.getService();
+    	IMemorySpaces service = fMemorySpaceServiceTracker.getService();
     	if (service != null) {
     		final IMemorySpaces.DecodeResult result = service.decodeAddress(str);
     		if (result != null) {	// service can return null to tell use to use default decoding 
@@ -265,13 +315,18 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
     	}
     	
     	// default decoding
+    	final String memorySpaceID;
+    	final String expression;
 		int index = str.indexOf(':');
 		if (index == -1) {
-			throw new CoreException(new Status(IStatus.ERROR, GdbPlugin.PLUGIN_ID, -1, Messages.Err_InvalidEncodedAddress + ": " + str , null)); //$NON-NLS-1$
+			//Unknown parsing, may not use memory spaces
+			memorySpaceID = null;
+			expression = str;
+		} else {
+			memorySpaceID = str.substring(0, index);
+			expression = (index < str.length()-1) ? str.substring(index+1) : ""; //$NON-NLS-1$
 		}
 
-		final String memorySpaceID = str.substring(0, index);
-		final String expression = (index < str.length()-1) ? str.substring(index+1) : ""; //$NON-NLS-1$
 		return new DecodeResult() {
 			@Override
 			public String getMemorySpaceId() { return memorySpaceID; }
@@ -280,8 +335,69 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 		};
  
 	}
+	
+	/**
+	 * Decode the received expression by
+	 * First, decoding the string directly
+	 * Second, if the memory space is not found in the expression string, use the Memory service to use some help from gdb
+	 */
+	private DecodeResult decodeMemorySpaceExpression(final IDMContext dmc, final String expression) throws DebugException {
+		DecodeResult decodeResult;
+		try {
+			decodeResult = decodeAddress(expression);
+		} catch (CoreException e1) {
+			throw new DebugException(e1.getStatus());
+		}
+		
+		if (decodeResult.getMemorySpaceId() != null) {
+			//memory space found in expression
+			return decodeResult;
+		}
+		
+		//
+    	final IMemorySpaces service = fMemorySpaceServiceTracker.getService();
+		if (service instanceof IMemorySpaces2) {
+			final IMemorySpaces2 memSpaceService = (IMemorySpaces2) service;
+			
+			Query<IMemorySpaces.DecodeResult> query = new Query<IMemorySpaces.DecodeResult>() {
+				@Override
+				protected void execute(final DataRequestMonitor<IMemorySpaces.DecodeResult> drm) {
+					memSpaceService.decodeExpression(dmc, expression, drm);
+				}
+			};
+			
+			getExecutor().execute(query);
+			try {
+				final IMemorySpaces.DecodeResult result = query.get();
+				decodeResult = new DecodeResult() {
+					@Override
+					public String getMemorySpaceId() {
+						return result.getMemorySpaceId();
+					}
+					
+					@Override
+					public String getExpression() {
+						return result.getExpression();
+					}
+				};
+			} catch (InterruptedException e) {
+				throw new DebugException(new Status(IStatus.ERROR,
+						GdbPlugin.PLUGIN_ID, DebugException.INTERNAL_ERROR,
+						"Error evaluating memory space expression (InterruptedException).", e)); //$NON-NLS-1$
 
-	ServiceTracker getMemorySpaceServiceTracker() {
+			} catch (ExecutionException e) {
+				throw new DebugException(new Status(IStatus.ERROR,
+						GdbPlugin.PLUGIN_ID, DebugException.INTERNAL_ERROR,
+						"Error evaluating memory space expression (ExecutionException).", e)); //$NON-NLS-1$
+			}
+			
+    	}
+		
+		return decodeResult;
+	}
+	
+	
+	ServiceTracker<IMemorySpaces, IMemorySpaces> getMemorySpaceServiceTracker() {
 		return fMemorySpaceServiceTracker;
 	}
 	
@@ -359,11 +475,19 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
                         	if (memorySpaceID.length() == 0) {
                         		memorySpaceID = null; 
                         		assert false : "should have either no memory space or a valid (non-empty) ID"; //$NON-NLS-1$	
+                        	} else {
+                        		if (memoryCtx instanceof IMemorySpaceDMContext) {
+                        			//The context is already a memory space context, make sure the ids are consistent
+                        			assert(((IMemorySpaceDMContext) memoryCtx).getMemorySpaceId().equals(memorySpaceID));
+                        		} else {
+                                    //Use a memory space context if the memory space id is valid
+                            		memoryCtx = new MemorySpaceDMContext(getSession().getId(), memorySpaceID, memoryCtx);
+                        		}
                         	}
                         }
 
                         BigInteger blockAddress = new BigInteger(address);
-                        DsfMemoryBlock block = new GdbMemoryBlock(this, memoryCtx, getModelId(), label, blockAddress, getAddressableSize(), 0, memorySpaceID);
+                        DsfMemoryBlock block = new GdbMemoryBlock(this, memoryCtx, getModelId(), label, blockAddress, getAddressableSize(memoryCtx), 0, memorySpaceID);
                         blocks.add(block);
                     }
                 }
@@ -377,10 +501,29 @@ public class GdbMemoryBlockRetrieval extends DsfMemoryBlockRetrieval implements
 	 */
 	@Override
 	public boolean creatingBlockRequiresMemorySpaceID() {
-		IMemorySpaces service = (IMemorySpaces)fMemorySpaceServiceTracker.getService();
+		IMemorySpaces service = fMemorySpaceServiceTracker.getService();
         if (service != null) {
         	return service.creatingBlockRequiresMemorySpaceID();
         }
 		return false;
 	}
+	
+	private int getAddressableSize(IMemoryDMContext context) {
+		IGDBMemory2 memoryService = (IGDBMemory2) getServiceTracker()
+				.getService();
+		
+		if (memoryService != null && context != null) {
+			return memoryService.getAddressableSize(context);
+		}
+		
+		return super.getAddressableSize();
+	}
+	
+	private int getAddressSize(IMemoryDMContext context) {
+		IGDBMemory memoryService = (IGDBMemory)getServiceTracker().getService();
+		if (memoryService != null && context != null) {
+			return memoryService.getAddressSize(context);
+		}
+		return super.getAddressSize();
+	}
 }
