@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2014 Ericsson and others.
+ * Copyright (c) 2010, 2015 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,6 +11,7 @@
  *     Sergey Prigogin (Google)
  *     Marc Khouzam (Ericsson) - Add timer when fetching GDB version (Bug 376203)
  *     Marc Khouzam (Ericsson) - Better error reporting when obtaining GDB version (Bug 424996)
+ *     Iulia Vasii (Freescale Semiconductor) - Separate GDB command from its arguments (Bug 445360)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.gdb.launching;
 
@@ -36,6 +37,7 @@ import org.eclipse.cdt.core.envvar.IEnvironmentVariable;
 import org.eclipse.cdt.core.model.CoreModel;
 import org.eclipse.cdt.core.model.CoreModelUtil;
 import org.eclipse.cdt.core.model.ICProject;
+import org.eclipse.cdt.core.parser.util.StringUtil;
 import org.eclipse.cdt.core.settings.model.ICConfigExtensionReference;
 import org.eclipse.cdt.core.settings.model.ICConfigurationDescription;
 import org.eclipse.cdt.core.settings.model.ICProjectDescription;
@@ -44,6 +46,7 @@ import org.eclipse.cdt.dsf.gdb.IGDBLaunchConfigurationConstants;
 import org.eclipse.cdt.dsf.gdb.IGdbDebugPreferenceConstants;
 import org.eclipse.cdt.dsf.gdb.internal.GdbPlugin;
 import org.eclipse.cdt.dsf.gdb.service.SessionType;
+import org.eclipse.cdt.utils.CommandLineUtil;
 import org.eclipse.cdt.utils.spawner.ProcessFactory;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IProject;
@@ -297,11 +300,15 @@ public class LaunchUtils {
 	 * A timeout is scheduled which will kill the process if it takes too long.
 	 */
 	public static String getGDBVersion(final ILaunchConfiguration configuration) throws CoreException {        
-        String cmd = getGDBPath(configuration).toOSString() + " --version"; //$NON-NLS-1$ 
+        String cmd = getGDBPath(configuration).toOSString() + " --version"; //$NON-NLS-1$
+        
+        // Parse cmd to properly handle spaces and such things (bug 458499)
+		String[] args = CommandLineUtil.argumentsToArray(cmd);
+        
         Process process = null;
         Job timeoutJob = null;
         try {
-        	process = ProcessFactory.getFactory().exec(cmd, getLaunchEnvironment(configuration));
+        	process = ProcessFactory.getFactory().exec(args, getLaunchEnvironment(configuration));
 
             // Start a timeout job to make sure we don't get stuck waiting for
             // an answer from a gdb that is hanging
@@ -336,13 +343,13 @@ public class LaunchUtils {
         		}
         		
         		throw new DebugException(new Status(IStatus.ERROR, GdbPlugin.PLUGIN_ID, DebugException.REQUEST_FAILED, 
-        				"Could not determine GDB version using command: " + cmd, //$NON-NLS-1$ 
+        				"Could not determine GDB version using command: " + StringUtil.join(args, " "), //$NON-NLS-1$ //$NON-NLS-2$ 
         				detailedException));
         	}
         	return gdbVersion;
         } catch (IOException e) {
         	throw new DebugException(new Status(IStatus.ERROR, GdbPlugin.PLUGIN_ID, DebugException.REQUEST_FAILED, 
-        			"Error with command: " + cmd, e));//$NON-NLS-1$
+        			"Error with command: " + StringUtil.join(args, " "), e));//$NON-NLS-1$ //$NON-NLS-2$
         } finally {
         	// If we get here we are obviously not stuck reading the stream so we can cancel the timeout job.
         	// Note that it may already have executed, but that is not a problem.
