@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson and others.
+ * Copyright (c) 2012, 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     Marc Khouzam (Ericsson) - initial API and implementation
+ *     Alvaro Sanchez-Leon (Ericsson) - Bug 235747
  *******************************************************************************/
 package org.eclipse.cdt.dsf.gdb.service;
 
@@ -24,6 +25,10 @@ class Messages extends NLS {
 	public static String NoMatches;
 	public static String UniqueMatch;
 	public static String UniqueMatches;
+	public static String ErrorNotSupported;
+	public static String RegisterGroup_name_reserved;
+	public static String RegisterGroup_name_used;
+	public static String RegisterGroup_invalid_number_of_registers;
 	
 	static {
 		// initialize resource bundle
