@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2009 Ericsson and others.
+ * Copyright (c) 2007, 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  * 
  * Contributors:
  *     Ericsson			  - Initial Implementation
+ *     Vladimir Prus (Mentor Graphics) - Use MITuple.getMIValue.
  *******************************************************************************/
 
 package org.eclipse.cdt.dsf.mi.service.command.output;
@@ -27,19 +28,12 @@ public class MIStackInfoDepthInfo extends MIInfo {
             MIOutput out = getMIOutput();
             MIResultRecord rr = out.getMIResultRecord();
             if (rr != null) {
-                MIResult[] results =  rr.getMIResults();
-                for (int i = 0; i < results.length; i++) {
-                    String var = results[i].getVariable();
-
-                    if (var.equals("depth")) { //$NON-NLS-1$
-                        MIValue value = results[i].getMIValue();
-                        if (value instanceof MIConst) {
-                            String str = ((MIConst)value).getString();
-                            try {
-                                depth = Integer.parseInt(str.trim());
-                            } catch (NumberFormatException e) {
-                            }
-                        }
+                MIValue value = rr.getField("depth"); //$NON-NLS-1$
+                if (value instanceof MIConst) {
+                    String str = ((MIConst)value).getString();
+                    try {
+                        depth = Integer.parseInt(str.trim());
+                    } catch (NumberFormatException e) {
                     }
                 }
             }
