@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013 Ericsson and others.
+ * Copyright (c) 2013, 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  * 
  * Contributors:
  *     Alvaro Sanchez-Leon (Ericsson AB) - Support for Step into selection (bug 244865)
+ *     Simon Marchi (Ericsson) - Fix atDoubleMethod* tests for older gdb (<= 7.3)
  *******************************************************************************/
 package org.eclipse.cdt.tests.dsf.gdb.tests;
 
@@ -36,6 +37,7 @@ import org.eclipse.cdt.tests.dsf.gdb.framework.BaseTestCase;
 import org.eclipse.cdt.tests.dsf.gdb.framework.ServiceEventWaitor;
 import org.eclipse.cdt.tests.dsf.gdb.framework.SyncUtil;
 import org.eclipse.cdt.tests.dsf.gdb.launching.TestsPlugin;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
@@ -52,8 +54,9 @@ public class StepIntoSelectionTest extends BaseTestCase {
 
 	private IRunControl3 fRunCtrl;
 
-	private static final String SRC_FILE = "StepIntoSelectionTestApp.cc";
-	private static final String HDR_FILE = "StepIntoSelection.h";
+	private static final String EXEC_NAME = "StepIntoSelectionTestApp.exe";
+	private static final String SOURCE_NAME = "StepIntoSelectionTestApp.cc";
+	private static final String HEADER_NAME = "StepIntoSelection.h";
 	private static final int FOO_LINE = 11;
 	private static final int BAR_LINE = 20;
 	private static final int VALUE_LINE = 5;
@@ -117,7 +120,7 @@ public class StepIntoSelectionTest extends BaseTestCase {
 	@Override
 	protected void setLaunchAttributes() {
 		super.setLaunchAttributes();
-		setLaunchAttribute(ICDTLaunchConfigurationConstants.ATTR_PROGRAM_NAME, "data/launch/bin/StepIntoSelectionTestApp.exe");
+		setLaunchAttribute(ICDTLaunchConfigurationConstants.ATTR_PROGRAM_NAME, EXEC_PATH + EXEC_NAME);
 	}
 
 	private void validateLocation(ISuspendedDMEvent suspendedEvent, String expectedFunction, 
@@ -222,10 +225,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcFoo;
         
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															stoppedEvent.getFrame().getLine(), targetFunction, false);
         
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, FOO_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, FOO_LINE, originalDepth + 1);
 	}
 	
 	/**
@@ -239,10 +242,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcFoo;
         int line = stoppedEvent.getFrame().getLine() + 3; // The method to stepInto is three lines below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, FOO_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, FOO_LINE, originalDepth + 1);
 	}
 
 	/**
@@ -256,10 +259,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcValue;
         int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), HDR_FILE, VALUE_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), HEADER_NAME, VALUE_LINE, originalDepth + 1);
 	}
 	
 	/**
@@ -274,10 +277,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcFoo;
         int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, FOO_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, FOO_LINE, originalDepth + 1);
 	}
 
 	/**
@@ -292,10 +295,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcBar;
         int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, BAR_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, BAR_LINE, originalDepth + 1);
 	}
 
 	/**
@@ -311,10 +314,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
 
         int line = stoppedEvent.getFrame().getLine() + 2; // The method to stepInto is two lines below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
         
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, finalLine, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, finalLine, originalDepth + 1);
 	}
 	
 	/**
@@ -338,10 +341,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
         int line = originalLine + 3; // The method to stepInto is three lines below the start of the method
         
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false);
 
-        validateLocation(suspendedEvent, functionName, SRC_FILE, bpline, originalDepth);
+        validateLocation(suspendedEvent, functionName, SOURCE_NAME, bpline, originalDepth);
 	}
 	
 	/**
@@ -362,16 +365,16 @@ public class StepIntoSelectionTest extends BaseTestCase {
         SyncUtil.addBreakpoint(Integer.toString(bpline));
 
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, false); // Don't skip breakpoints
 
-        validateLocation(suspendedEvent, functionName, SRC_FILE, bpline, originalDepth);
+        validateLocation(suspendedEvent, functionName, SOURCE_NAME, bpline, originalDepth);
 
         // Make sure the step to selection operation is no longer active by triggering a run to line before the step into selection line
-        suspendedEvent = triggerRunToLine(stoppedEvent.getDMContext(), SRC_FILE, 
+        suspendedEvent = triggerRunToLine(stoppedEvent.getDMContext(), SOURCE_NAME,
 										  bpline + 1, false);
         
-        validateLocation(suspendedEvent, functionName, SRC_FILE, bpline + 1, originalDepth);        
+        validateLocation(suspendedEvent, functionName, SOURCE_NAME, bpline + 1, originalDepth);
 
 	}
 	
@@ -391,16 +394,16 @@ public class StepIntoSelectionTest extends BaseTestCase {
         
         int line = originalLine + 3; // The method to stepInto is three lines below the start of the method
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, funcFoo, false);
 
-        validateLocation(suspendedEvent, functionName, SRC_FILE, originalLine + 1, originalDepth);
+        validateLocation(suspendedEvent, functionName, SOURCE_NAME, originalLine + 1, originalDepth);
 
 		// Make sure the step to selection operation is no longer active by triggering a run to line before the step into selection line
-        suspendedEvent = triggerRunToLine(stoppedEvent.getDMContext(), SRC_FILE, 
+        suspendedEvent = triggerRunToLine(stoppedEvent.getDMContext(), SOURCE_NAME,
 										  originalLine + 2, false);
         
-        validateLocation(suspendedEvent, functionName, SRC_FILE, originalLine + 2, originalDepth);        
+        validateLocation(suspendedEvent, functionName, SOURCE_NAME, originalLine + 2, originalDepth);
 	}
 	
 	/**
@@ -422,56 +425,92 @@ public class StepIntoSelectionTest extends BaseTestCase {
         FunctionDeclaration targetFunction = funcFoo;
 
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															line, targetFunction, true);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, FOO_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, FOO_LINE, originalDepth + 1);
 	}
-	
+
+	private void atDoubleMethodStopAtBreakpointCommon(int foo_line) throws Throwable {
+		MIStoppedEvent stoppedEvent = SyncUtil.runToLocation("doubleMethodTest");
+		int originalDepth = SyncUtil.getStackDepth(stoppedEvent.getDMContext());
+
+		// Set a breakpoint inside foo, which will hit before our
+		// StepInto is finished
+		SyncUtil.addBreakpoint(Integer.toString(foo_line));
+
+		FunctionDeclaration targetFunction = funcBar;
+		int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
+		// StepInto the method
+		ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
+																	line, targetFunction, false);  // Set not to skip breakpoints, but it should have no effect
+
+			validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, BAR_LINE, originalDepth + 1);
+	}
+
 	/**
 	 * This test verifies that we will not stop at a breakpoint if it is in the middle
 	 * of the step-in operations when the run-to-line skip breakpoint option is not selected.
+	 *
+	 * It is only enabled for gdb > 7.3. gdb <= 7.3 generates a stopped event with two
+	 * reasons, resulting in two MIStoppedEvent in the step-into-selection machinery. Later
+	 * gdbs generate a stopped event with only one reason, as they should.
+	 */
+	@Ignore
+	@Test
+	public void atDoubleMethodStopAtBreakpointFunctionEntry() throws Throwable {
+		atDoubleMethodStopAtBreakpointCommon(FOO_LINE);
+	}
+
+	/**
+	 * This test is just like atDoubleMethodStopAtBreakpointFunctionEntry, but avoids placing
+	 * the breakpoint at the beginning of foo().
 	 */
 	@Test
 	public void atDoubleMethodStopAtBreakpoint() throws Throwable {
-        MIStoppedEvent stoppedEvent = SyncUtil.runToLocation("doubleMethodTest");
-        int originalDepth = SyncUtil.getStackDepth(stoppedEvent.getDMContext());
-
-        // Set a breakpoint inside foo, which will hit before our
-        // StepInto is finished
-        SyncUtil.addBreakpoint(Integer.toString(FOO_LINE));
-
-        FunctionDeclaration targetFunction = funcBar;
-        int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
-        // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
-        															line, targetFunction, false);  // Set not to skip breakpoints, but it should have no effect
-
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, BAR_LINE, originalDepth + 1);
+		atDoubleMethodStopAtBreakpointCommon(FOO_LINE + 1);
 	}
-	
+
+	private void atDoubleMethodSkipBreakpointCommon(int foo_line) throws Throwable {
+		MIStoppedEvent stoppedEvent = SyncUtil.runToLocation("doubleMethodTest");
+		int originalDepth = SyncUtil.getStackDepth(stoppedEvent.getDMContext());
+
+		// Set a breakpoint inside foo, which will hit before our
+		// StepInto is finished
+		SyncUtil.addBreakpoint(Integer.toString(foo_line));
+
+		FunctionDeclaration targetFunction = funcBar;
+		int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
+		// StepInto the method
+		ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
+																	line, targetFunction, true);  // Set skip breakpoints, which should have non impact
+
+		validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, BAR_LINE, originalDepth + 1);
+	}
+
 	/**
 	 * This test verifies that we will not stop at a breakpoint if it is in the middle
-	 * of the step-in operations even if the run-to-line skip breakpoint option is selected. 
+	 * of the step-in operations even if the run-to-line skip breakpoint option is selected.
+	 *
+	 * It is only enabled for gdb > 7.3. gdb <= 7.3 generates a stopped event with two
+	 * reasons, resulting in two MIStoppedEvent in the step-into-selection machinery. Later
+	 * gdbs generate a stopped event with only one reason, as they should.
+	 */
+	@Test
+	@Ignore
+	public void atDoubleMethodSkipBreakpointFunctionEntry() throws Throwable {
+		atDoubleMethodSkipBreakpointCommon(FOO_LINE);
+	}
+
+	/**
+	 * This test is just like atDoubleMethodSkipBreakpointFunctionEntry, but avoids placing
+	 * the breakpoint at the beginning of foo().
 	 */
 	@Test
 	public void atDoubleMethodSkipBreakpoint() throws Throwable {
-        MIStoppedEvent stoppedEvent = SyncUtil.runToLocation("doubleMethodTest");
-        int originalDepth = SyncUtil.getStackDepth(stoppedEvent.getDMContext());
-
-        // Set a breakpoint inside foo, which will hit before our
-        // StepInto is finished
-        SyncUtil.addBreakpoint(Integer.toString(FOO_LINE));
-
-        FunctionDeclaration targetFunction = funcBar;
-        int line = stoppedEvent.getFrame().getLine() + 1; // The method to stepInto is one line below the start of the method
-        // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
-        															line, targetFunction, true);  // Set skip breakpoints, which should have non impact
-
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, BAR_LINE, originalDepth + 1);
+		atDoubleMethodSkipBreakpointCommon(FOO_LINE + 1);
 	}
-	
+
 	/**
 	 * This test verifies that if we have two methods with the same name on the same line,
 	 * we properly choose the method with the correct number of arguments based on the
@@ -484,10 +523,10 @@ public class StepIntoSelectionTest extends BaseTestCase {
 
         FunctionDeclaration targetFunction = funcAddWithArg;
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															stoppedEvent.getFrame().getLine(), targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, ADD_WITH_ARG_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, ADD_WITH_ARG_LINE, originalDepth + 1);
 	}
 
 	@Test
@@ -497,9 +536,9 @@ public class StepIntoSelectionTest extends BaseTestCase {
 
         FunctionDeclaration targetFunction = funcAddNoArg;
         // StepInto the method     
-        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SRC_FILE, 
+        ISuspendedDMEvent suspendedEvent = triggerStepIntoSelection(stoppedEvent.getDMContext(), SOURCE_NAME,
         															stoppedEvent.getFrame().getLine(), targetFunction, false);
 
-        validateLocation(suspendedEvent, targetFunction.getElementName(), SRC_FILE, ADD_NO_ARG_LINE, originalDepth + 1);
+        validateLocation(suspendedEvent, targetFunction.getElementName(), SOURCE_NAME, ADD_NO_ARG_LINE, originalDepth + 1);
 	}
 }
