@@ -8,18 +8,18 @@
  * Contributors:
  *     Marc Khouzam (Ericsson) - Support for Step into selection (bug 244865)
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_4;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_6_6;
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_3.StepIntoSelectionTest_7_3;
+import org.eclipse.cdt.tests.dsf.gdb.tests.StepIntoSelectionTest;
 import org.junit.runner.RunWith;
 
 
 @RunWith(BackgroundRunner.class)
-public class StepIntoSelectionTest_7_4 extends StepIntoSelectionTest_7_3 {
+public class StepIntoSelectionTest_6_6 extends StepIntoSelectionTest {
     @Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_4);		
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_6_6);		
 	}
 }
