@@ -8,18 +8,18 @@
  * Contributors:
  *     Ericsson	AB		  - Initial implementation of Test cases
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_6_6;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_1;
 
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.MIRunControlTargetAvailableTest;
+import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_0.MIRunControlTargetAvailableTest_7_0;
 import org.junit.runner.RunWith;
 
 @RunWith(BackgroundRunner.class)
-public class MIRunControlTargetAvailableTest_6_6 extends MIRunControlTargetAvailableTest {
+public class MIRunControlTargetAvailableTest_7_1 extends MIRunControlTargetAvailableTest_7_0 {
 	@Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_6_6);
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_1);
 	}
 }
