@@ -1,26 +1,26 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Ericsson and others.
+ * Copyright (c) 2012 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  * 
  * Contributors:
- *     Ericsson - Initial Implementation
+ *     Marc Khouzam (Ericsson) - Initial implementation of Test cases
  *******************************************************************************/
 
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_6_6;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_6;
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.MIDisassemblyTest;
+import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_5.MIDisassemblyTest_7_5;
 import org.junit.runner.RunWith;
 
 
 @RunWith(BackgroundRunner.class)
-public class MIDisassemblyTest_6_6 extends MIDisassemblyTest {
+public class MIDisassemblyTest_7_6 extends MIDisassemblyTest_7_5 {
     @Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_6_6);		
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_6);		
 	}
 }
