@@ -1,28 +1,25 @@
 /*******************************************************************************
- * Copyright (c) 2010 Ericsson and others.
+ * Copyright (c) 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  * 
  * Contributors:
- *     Ericsson - Initial implementation of Test cases
+ *     Marc Khouzam (Ericsson) - Initial implementation of Test cases
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_2;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_7;
 
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_1.GDBRemoteTracepointsTest_7_1;
+import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_6.GDBRemoteTracepointsTest_7_6;
 import org.junit.runner.RunWith;
 
 @RunWith(BackgroundRunner.class)
-public class GDBRemoteTracepointsTest_7_2 extends GDBRemoteTracepointsTest_7_1 {
+public class GDBRemoteTracepointsTest_7_7 extends GDBRemoteTracepointsTest_7_6 {
 	@Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_2);		
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_7);
 	}
-	
-	@Override
-	protected boolean fastTracepointsSupported() { return true;	}
 }
