@@ -1,24 +1,24 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Ericsson and others.
+ * Copyright (c) 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  * 
  * Contributors:
- *     Ericsson	AB		- Initial Implementation
+ *     Marc Khouzam (Ericsson) - Initial implementation of Test cases
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_6_6;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_7;
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.MIRegistersTest;
+import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_6.MIRegistersTest_7_6;
 import org.junit.runner.RunWith;
 
 @RunWith(BackgroundRunner.class)
-public class MIRegistersTest_6_6 extends MIRegistersTest {
+public class MIRegistersTest_7_7 extends MIRegistersTest_7_6 {
     @Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_6_6);		
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_7);
 	}
 }
