@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2010 Wind River Systems and others.
+ * Copyright (c) 2006, 2014 Wind River Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,10 +7,12 @@
  * 
  * Contributors:
  *     Wind River Systems - initial API and implementation
+ *     Marc Khouzam (Ericsson) - Enable per-element formatting (Bug 439624)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.debug.ui.viewmodel.register;
 
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.RejectedExecutionException;
 
 import org.eclipse.cdt.dsf.concurrent.ConfinedToDsfExecutor;
@@ -41,6 +43,7 @@ import org.eclipse.cdt.dsf.debug.ui.viewmodel.numberformat.FormattedValueLabelTe
 import org.eclipse.cdt.dsf.debug.ui.viewmodel.numberformat.FormattedValueRetriever;
 import org.eclipse.cdt.dsf.debug.ui.viewmodel.numberformat.IFormattedValueVMContext;
 import org.eclipse.cdt.dsf.debug.ui.viewmodel.register.RegisterBitFieldCellModifier.BitFieldEditorStyle;
+import org.eclipse.cdt.dsf.debug.ui.viewmodel.update.ElementFormatEvent;
 import org.eclipse.cdt.dsf.debug.ui.viewmodel.variable.VariableLabelFont;
 import org.eclipse.cdt.dsf.internal.ui.DsfUIPlugin;
 import org.eclipse.cdt.dsf.service.DsfSession;
@@ -967,6 +970,13 @@ public class RegisterBitFieldVMNode extends AbstractExpressionVMNode
             return IModelDelta.CONTENT;
         }
         
+        if (event instanceof ElementFormatEvent) {
+        	int depth = ((ElementFormatEvent)event).getApplyDepth();
+        	if (depth == 0) return IModelDelta.NO_CHANGE;
+        	if (depth == 1) return IModelDelta.STATE;
+            return IModelDelta.CONTENT;
+        }
+        
         return IModelDelta.NO_CHANGE;
     }
     
@@ -1001,7 +1011,20 @@ public class RegisterBitFieldVMNode extends AbstractExpressionVMNode
         {
             parentDelta.addNode(element, IModelDelta.STATE);
         } 
+        else if (event instanceof ElementFormatEvent) 
+        {
+        	int depth = ((ElementFormatEvent)event).getApplyDepth();
+        	if (depth != 0) {
+        		int deltaType = IModelDelta.CONTENT;
+        		if (depth == 1) deltaType = IModelDelta.STATE;
 
+        		Set<Object> elements = ((ElementFormatEvent)event).getElements();
+        		for (Object elem : elements) {
+        			parentDelta.addNode(elem, deltaType);
+        		}
+        	}
+        }
+        
         rm.done();
     }
     
