@@ -26,9 +26,11 @@ import org.eclipse.cdt.internal.core.pdom.dom.FindBinding;
 import org.eclipse.cdt.internal.core.pdom.dom.IPDOMBinding;
 import org.eclipse.cdt.internal.core.pdom.dom.PDOMBinding;
 import org.eclipse.cdt.internal.core.pdom.dom.PDOMFile;
+import org.eclipse.cdt.internal.core.pdom.dom.PDOMGlobalScope;
 import org.eclipse.cdt.internal.core.pdom.dom.PDOMLinkage;
 import org.eclipse.cdt.internal.core.pdom.dom.PDOMName;
 import org.eclipse.cdt.internal.core.pdom.dom.PDOMNode;
+import org.eclipse.cdt.internal.core.pdom.dom.cpp.PDOMCPPGlobalScope;
 import org.eclipse.cdt.qt.core.QtPlugin;
 import org.eclipse.core.runtime.CoreException;
 
@@ -107,6 +109,11 @@ public class QtPDOMLinkage extends PDOMLinkage {
 		return new FindBinding.DefaultBindingBTreeComparator(this);
 	}
 
+	@Override
+	public PDOMGlobalScope getGlobalScope() {
+		return PDOMCPPGlobalScope.INSTANCE;
+	}
+
 	// IBinding#getAdapter cannot create an instance of PDOMBinding because the Linkage is required.  This
 	// utility method uses #getAdapter to see if an instance has already been created.  If not then a new
 	// is created and stored in the AST binding.
